@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,31 +33,34 @@
 
 #include <common/objectbroker.h>
 #include <common/paths.h>
+#include <common/translator.h>
 
 #include <QApplication>
 #include <QStringList>
 
 using namespace GammaRay;
 
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
-  QApplication app(argc, argv);
-  Paths::setRelativeRootPath(GAMMARAY_INVERSE_LIBEXEC_DIR);
-  ClientConnectionManager::init();
+    QApplication app(argc, argv);
+    Paths::setRelativeRootPath(GAMMARAY_INVERSE_LIBEXEC_DIR);
+    Translator::loadStandAloneTranslations();
+    ClientConnectionManager::init();
 
-  QUrl serverUrl;
-  if (app.arguments().size() == 2) {
-    serverUrl = QUrl::fromUserInput(app.arguments().at(1));
-  } else {
-    serverUrl.setScheme(QStringLiteral("tcp"));
-    serverUrl.setHost(QStringLiteral("127.0.0.1"));
-    serverUrl.setPort(Client::defaultPort());
-  }
+    QUrl serverUrl;
+    if (app.arguments().size() == 2) {
+        serverUrl = QUrl::fromUserInput(app.arguments().at(1));
+    } else {
+        serverUrl.setScheme(QStringLiteral("tcp"));
+        serverUrl.setHost(QStringLiteral(GAMMARAY_DEFAULT_LOCAL_ADDRESS));
+        serverUrl.setPort(Client::defaultPort());
+    }
 
-  ClientConnectionManager conMan;
-  QObject::connect(&conMan, SIGNAL(ready()), &conMan, SLOT(createMainWindow()));
-  QObject::connect(&conMan, SIGNAL(disconnected()), QApplication::instance(), SLOT(quit()));
-  QObject::connect(&conMan, SIGNAL(persistentConnectionError(QString)), &conMan, SLOT(handlePersistentConnectionError(QString)));
-  conMan.connectToHost(serverUrl);
-  return app.exec();
+    ClientConnectionManager conMan;
+    QObject::connect(&conMan, SIGNAL(ready()), &conMan, SLOT(createMainWindow()));
+    QObject::connect(&conMan, SIGNAL(disconnected()), QApplication::instance(), SLOT(quit()));
+    QObject::connect(&conMan, SIGNAL(persistentConnectionError(QString)), &conMan,
+                     SLOT(handlePersistentConnectionError(QString)));
+    conMan.connectToHost(serverUrl);
+    return app.exec();
 }
