@@ -63,10 +63,48 @@ public:
     Protocol::ObjectAddress address() const;
     Protocol::MessageType type() const;
 
-    /** Access to the message payload. This is read-only for received messages
-     *  and write-only for messages to be sent.
+    /** Read value from the payload
+     *  This operator proxy over payload() allow to do:
+     *   - Run time check on the stream status
      */
-    QDataStream &payload() const;
+    template <typename T>
+    GammaRay::Message &operator>>(T &value)
+    {
+        if (Q_UNLIKELY(payload().status() != QDataStream::Ok)) {
+            qWarning("%s: Attempting to read from a non valid stream: status: %i", Q_FUNC_INFO, int(payload().status()));
+        }
+        payload() >> value;
+        if (Q_UNLIKELY(payload().status() != QDataStream::Ok)) {
+            qWarning("%s: Read from a non valid stream: status: %i", Q_FUNC_INFO, int(payload().status()));
+        }
+        return *this;
+    }
+
+    /** Read value from the payload
+     *  This overload allow to read content from a const Message.
+     */
+    template <typename T>
+    GammaRay::Message &operator>>(T &value) const
+    {
+        return const_cast<GammaRay::Message *>(this)->operator>>(value);
+    }
+
+    /** Write value to the payload.
+     *  This operator proxy over payload() allow to do:
+     *   - Run time check on the stream status
+     */
+    template <typename T>
+    GammaRay::Message &operator<<(const T &value)
+    {
+        if (Q_UNLIKELY(payload().status() != QDataStream::Ok)) {
+            qWarning("%s: Attempting to write to a non valid stream: status: %i", Q_FUNC_INFO, int(payload().status()));
+        }
+        payload() << value;
+        if (Q_UNLIKELY(payload().status() != QDataStream::Ok)) {
+            qWarning("%s: Write to a non valid stream: status: %i", Q_FUNC_INFO, int(payload().status()));
+        }
+        return *this;
+    }
 
     /** Checks if there is a full message waiting in @p device. */
     static bool canReadMessage(QIODevice *device);
@@ -82,6 +120,11 @@ public:
 private:
     Message();
 
+    /** Access to the message payload. This is read-only for received messages
+     *  and write-only for messages to be sent.
+     */
+    QDataStream &payload() const;
+
     mutable QByteArray m_buffer;
     mutable QScopedPointer<QDataStream> m_stream;
 
