@@ -28,10 +28,13 @@
 
 #include <config-gammaray.h>
 #include "paths.h"
+#include "selflocator.h"
 
 #include <QCoreApplication>
 #include <QDebug>
 #include <QDir>
+#include <QFileInfo>
+#include <QLibraryInfo>
 #include <QMutex>
 
 namespace GammaRay {
@@ -49,6 +52,12 @@ namespace Paths {
 QString rootPath()
 {
     QMutexLocker locker(&s_pathData()->mutex);
+    if (s_pathData()->rootPath.isEmpty()) {
+        QFileInfo fi(SelfLocator::findMe());
+        fi.setFile(fi.absolutePath() + QLatin1String("/" GAMMARAY_INVERSE_LIB_DIR));
+        if (fi.isDir())
+            s_pathData()->rootPath = fi.absoluteFilePath();
+    }
     Q_ASSERT(!s_pathData()->rootPath.isEmpty());
     return s_pathData()->rootPath;
 }
@@ -98,10 +107,41 @@ QString currentProbePath()
     return probePath(QStringLiteral(GAMMARAY_PROBE_ABI));
 }
 
+static void addPluginPath(QStringList &list, const QString &path)
+{
+    QFileInfo fi(path);
+    if (!fi.isDir())
+        return;
+    list.push_back(fi.canonicalFilePath());
+}
+
+QStringList pluginPaths(const QString &probeABI)
+{
+    QStringList l;
+    // TODO based on environment variable for custom plugins
+
+    // based on rootPath()
+    addPluginPath(l, rootPath() + QLatin1String("/" GAMMARAY_PLUGIN_INSTALL_DIR "/" GAMMARAY_PLUGIN_VERSION "/") + probeABI);
+    addPluginPath(l, rootPath() + QLatin1String("/" GAMMARAY_PLUGIN_INSTALL_DIR));
+
+    // based on Qt plugin search paths
+    foreach (const auto &path, QCoreApplication::libraryPaths()) {
+        addPluginPath(l, path + QLatin1String("/gammaray/" GAMMARAY_PLUGIN_VERSION "/") + probeABI);
+        addPluginPath(l, path + QLatin1String("/gammaray"));
+    }
+
+    // based on Qt's own install layout and/or qt.conf
+    const auto path = QLibraryInfo::location(QLibraryInfo::PluginsPath);
+    addPluginPath(l, path + QLatin1String("/gammaray/" GAMMARAY_PLUGIN_VERSION "/") + probeABI);
+    addPluginPath(l, path + QLatin1String("/gammaray"));
+
+    return l;
+}
+
 QString currentPluginsPath()
 {
 #ifndef GAMMARAY_INSTALL_QT_LAYOUT
-    return currentProbePath();
+    return probePath(QStringLiteral(GAMMARAY_PROBE_ABI));
 #else
     return rootPath() + QDir::separator() + QStringLiteral(GAMMARAY_PLUGIN_INSTALL_DIR);
 #endif
