@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  acuordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -25,31 +30,36 @@
 #define GAMMARAY_PROPERTYCONTROLLERINTERFACE_H
 
 #include <QObject>
+#include <QStringList>
 
-#include "enums.h"
-
-class QStringList;
 namespace GammaRay {
-
 /** @brief Client/Server interface of the property editor. */
 class PropertyControllerInterface : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+    Q_PROPERTY(
+        QStringList availableExtensions READ availableExtensions WRITE setAvailableExtensions NOTIFY availableExtensionsChanged)
+public:
     explicit PropertyControllerInterface(const QString &name, QObject *parent = 0);
     virtual ~PropertyControllerInterface();
 
     QString name() const;
 
-  signals:
-    void availableExtensionsChanged(const QStringList &availableExtensions);
+    QStringList availableExtensions() const;
+    void setAvailableExtensions(const QStringList &availableExtensions);
 
-  private:
+signals:
+    void availableExtensionsChanged();
+
+private:
     QString m_name;
+    QStringList m_availableExtensions;
 };
-
 }
 
-Q_DECLARE_INTERFACE(GammaRay::PropertyControllerInterface, "com.kdab.GammaRay.PropertyControllerInterface")
+QT_BEGIN_NAMESPACE
+Q_DECLARE_INTERFACE(GammaRay::PropertyControllerInterface,
+                    "com.kdab.GammaRay.PropertyControllerInterface")
+QT_END_NAMESPACE
 
 #endif // GAMMARAY_PROPERTYCONTROLLERINTERFACE_H
