@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -35,87 +35,100 @@
 #include <QModelIndex>
 #include <QPair>
 
-namespace GammaRay {
+#include <limits>
 
+namespace GammaRay {
 /** @brief Helper functions and constants defining the communication protocol between client and server. */
 namespace Protocol {
-
 typedef qint32 PayloadSize;
-typedef quint8 ObjectAddress;
+typedef quint16 ObjectAddress;
 typedef quint8 MessageType;
 
 static const ObjectAddress InvalidObjectAddress = 0;
-static const ObjectAddress LauncherAddress = 255;
+static const ObjectAddress LauncherAddress = std::numeric_limits<ObjectAddress>::max();
 static const MessageType InvalidMessageType = 0;
 
 enum BuildInMessageType {
-  // object management
-  // client -> server
-  ObjectMonitored = InvalidMessageType + 1,
-  ObjectUnmonitored,
+    // object management
+    // client -> server
+    ObjectMonitored = InvalidMessageType + 1,
+    ObjectUnmonitored,
 
-  // server -> client
-  ServerVersion,
+    // server -> client
+    ServerVersion,
 
-  ObjectMapReply,
-  ObjectAdded,
-  ObjectRemoved,
+    ObjectMapReply,
+    ObjectAdded,
+    ObjectRemoved,
 
-  // remote model messages
-  // client -> server
-  ModelRowColumnCountRequest,
-  ModelContentRequest,
-  ModelHeaderRequest,
-  ModelSetDataRequest,
-  ModelSortRequest,
-  ModelSyncBarrier,
+    // remote model messages
+    // client -> server
+    ModelRowColumnCountRequest,
+    ModelContentRequest,
+    ModelHeaderRequest,
+    ModelSetDataRequest,
+    ModelSortRequest,
+    ModelSyncBarrier,
+    SelectionModelStateRequest,
 
-  // server -> client
-  ModelRowColumnCountReply,
-  ModelContentReply,
-  ModelContentChanged,
-  ModelHeaderReply,
-  ModelHeaderChanged,
-  ModelRowsAdded,
-  ModelRowsMoved,
-  ModelRowsRemoved,
-  ModelColumnsAdded,
-  ModelColumnsMoved,
-  ModelColumnsRemoved,
-  ModelReset,
-  ModelLayoutChanged,
+    // server -> client
+    ModelRowColumnCountReply,
+    ModelContentReply,
+    ModelContentChanged,
+    ModelHeaderReply,
+    ModelHeaderChanged,
+    ModelRowsAdded,
+    ModelRowsMoved,
+    ModelRowsRemoved,
+    ModelColumnsAdded,
+    ModelColumnsMoved,
+    ModelColumnsRemoved,
+    ModelReset,
+    ModelLayoutChanged,
 
-  // server <-> client
-  SelectionModelSelect,
-  SelectionModelCurrent,
+    // server <-> client
+    SelectionModelSelect,
+    SelectionModelCurrent,
 
-  MethodCall,
-  PropertySyncRequest,
-  PropertyValuesChanged,
+    MethodCall,
+    PropertySyncRequest,
+    PropertyValuesChanged,
 
-  ServerInfo,
+    ServerInfo,
 
-  // probe settings provided by the launcher
-  ProbeSettings,
-  ServerAddress
+    // probe settings provided by the launcher
+    ProbeSettings,
+    ServerAddress,
+
+    MESSAGE_TYPE_COUNT // NOTE when changing this enum, also update MessageStatisticsModel!
 };
 
 typedef QVector<QPair<qint32, qint32> > ModelIndex;
 
+/** @brief Protocol representation of an QItemSelectionRange. */
+struct ItemSelectionRange {
+    ModelIndex topLeft;
+    ModelIndex bottomRight;
+};
+typedef QVector<ItemSelectionRange> ItemSelection;
+
 /** Serializes a QModelIndex. */
 GAMMARAY_COMMON_EXPORT ModelIndex fromQModelIndex(const QModelIndex &index);
 
 /** Deserializes a QModelIndex. */
-GAMMARAY_COMMON_EXPORT QModelIndex toQModelIndex(const QAbstractItemModel *model, const ModelIndex &index);
+GAMMARAY_COMMON_EXPORT QModelIndex toQModelIndex(const QAbstractItemModel *model,
+                                                 const ModelIndex &index);
 
 /** Protocol version, must match exactly between client and server. */
 GAMMARAY_COMMON_EXPORT qint32 version();
 
 /** Broadcast format version. */
 GAMMARAY_COMMON_EXPORT qint32 broadcastFormatVersion();
-
+}
 }
 
-}
+QT_BEGIN_NAMESPACE
+    Q_DECLARE_TYPEINFO(GammaRay::Protocol::ItemSelectionRange, Q_MOVABLE_TYPE);
+QT_END_NAMESPACE
 
 #endif
