@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  acuordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,11 +32,11 @@
 
 using namespace GammaRay;
 
-ConnectionsExtensionInterface::ConnectionsExtensionInterface(const QString& name, QObject* parent):
-  QObject(parent),
-  m_name(name)
+ConnectionsExtensionInterface::ConnectionsExtensionInterface(const QString &name, QObject *parent)
+    : QObject(parent)
+    , m_name(name)
 {
-  ObjectBroker::registerObject(name, this);
+    ObjectBroker::registerObject(name, this);
 }
 
 ConnectionsExtensionInterface::~ConnectionsExtensionInterface()
@@ -40,5 +45,5 @@ ConnectionsExtensionInterface::~ConnectionsExtensionInterface()
 
 QString ConnectionsExtensionInterface::name() const
 {
-  return m_name;
+    return m_name;
 }
