@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  acuordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,18 +32,31 @@
 using namespace GammaRay;
 
 MethodsExtensionInterface::MethodsExtensionInterface(const QString &name, QObject *parent)
-  : QObject(parent)
-  , m_name(name)
+    : QObject(parent)
+    , m_name(name)
+    , m_hasObject(false)
 {
-  ObjectBroker::registerObject(name, this);
+    ObjectBroker::registerObject(name, this);
 }
 
 MethodsExtensionInterface::~MethodsExtensionInterface()
 {
-
 }
 
 const QString &MethodsExtensionInterface::name() const
 {
-  return m_name;
+    return m_name;
+}
+
+bool MethodsExtensionInterface::hasObject() const
+{
+    return m_hasObject;
+}
+
+void MethodsExtensionInterface::setHasObject(bool hasObject)
+{
+    if (m_hasObject == hasObject)
+        return;
+    m_hasObject = hasObject;
+    emit hasObjectChanged();
 }
