@@ -29,8 +29,6 @@
 #ifndef GAMMARAY_METAOBJECTTREEMODEL_H
 #define GAMMARAY_METAOBJECTTREEMODEL_H
 
-#include <common/modelroles.h>
-
 #include <QModelIndex>
 #include <QSet>
 #include <QVector>
@@ -41,24 +39,12 @@ QT_END_NAMESPACE
 
 namespace GammaRay {
 class Probe;
-class MetaObjectInfoTracker;
 
 class MetaObjectTreeModel : public QAbstractItemModel
 {
     Q_OBJECT
 
 public:
-    enum Role {
-        MetaObjectRole = UserRole + 1
-    };
-
-    enum Column {
-        ObjectColumn,
-        ObjectSelfCountColumn,
-        ObjectInclusiveCountColumn,
-        _Last
-    };
-
     explicit MetaObjectTreeModel(Probe *probe);
     ~MetaObjectTreeModel();
 
@@ -73,9 +59,6 @@ public:
     QModelIndex index(int row, int column,
                       const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
 
-    QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-
     QModelIndexList match(const QModelIndex &start, int role, const QVariant &value, int hits,
                           Qt::MatchFlags flags) const Q_DECL_OVERRIDE;
 
