@@ -36,6 +36,11 @@ ObjectFilterProxyModelBase::ObjectFilterProxyModelBase(QObject *parent)
     setDynamicSortFilter(true);
 }
 
+QMap<int, QVariant> ObjectFilterProxyModelBase::itemData(const QModelIndex& index) const
+{
+    return sourceModel()->itemData(mapToSource(index));
+}
+
 bool ObjectFilterProxyModelBase::filterAcceptsRow(int source_row,
                                                   const QModelIndex &source_parent) const
 {
