@@ -59,6 +59,7 @@ class ProbeSettingsReceiver : public QObject
     Q_OBJECT
 public:
     explicit ProbeSettingsReceiver(QObject *parent = Q_NULLPTR);
+    ~ProbeSettingsReceiver();
     Q_INVOKABLE void sendServerAddress(const QUrl &address);
 
     void waitForSettingsReceived();
@@ -81,6 +82,11 @@ ProbeSettingsReceiver::ProbeSettingsReceiver(QObject *parent)
 {
 }
 
+ProbeSettingsReceiver::~ProbeSettingsReceiver()
+{
+    delete m_socket;
+}
+
 void ProbeSettingsReceiver::run()
 {
     m_mutex.lock(); // we only need this for ordering run after waitForSettingsReceived
@@ -116,7 +122,7 @@ void ProbeSettingsReceiver::readyRead()
         case Protocol::ServerVersion:
         {
             qint32 version;
-            msg.payload() >> version;
+            msg >> version;
             if (version != Protocol::version()) {
                 qWarning()
                         <<
@@ -130,7 +136,7 @@ void ProbeSettingsReceiver::readyRead()
         }
         case Protocol::ProbeSettings:
         {
-            msg.payload() >> s_probeSettings()->settings;
+            msg >> s_probeSettings()->settings;
             // qDebug() << Q_FUNC_INFO << s_probeSettings()->settings;
             const QString probePath = ProbeSettings::value(QStringLiteral("ProbePath")).toString();
             setRootPathFromProbePath(probePath);
@@ -150,7 +156,7 @@ void ProbeSettingsReceiver::sendServerAddress(const QUrl &address)
         return;
 
     Message msg(Protocol::LauncherAddress, Protocol::ServerAddress);
-    msg.payload() << address;
+    msg << address;
     msg.write(m_socket);
 
     m_socket->waitForBytesWritten();
