@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -26,17 +31,34 @@
 
 #include <common/networkselectionmodel.h>
 
-namespace GammaRay {
+QT_BEGIN_NAMESPACE
+class QTimer;
+QT_END_NAMESPACE
 
+namespace GammaRay {
 /** Server-side of the network transparent QItemSelection model. */
 class SelectionModelServer : public NetworkSelectionModel
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
-  explicit SelectionModelServer(const QString& objectName, QAbstractItemModel* model, QObject* parent);
-  ~SelectionModelServer();
-};
+    explicit SelectionModelServer(const QString &objectName, QAbstractItemModel *model,
+                                  QObject *parent);
+    ~SelectionModelServer();
 
+protected:
+    bool isConnected() const Q_DECL_OVERRIDE;
+
+private slots:
+    void timeout();
+    void modelMonitored(bool monitored = false);
+
+private:
+    void connectModel();
+    void disconnectModel();
+
+    QTimer *m_timer;
+    bool m_monitored;
+};
 }
 
 #endif // GAMMARAY_SELECTIONMODELSERVER_H
