@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,9 +29,9 @@
 
 using namespace GammaRay;
 
-ToolPluginModel::ToolPluginModel(const QVector<ToolFactory*> &plugins, QObject* parent):
-  QAbstractTableModel(parent),
-  m_tools(plugins)
+ToolPluginModel::ToolPluginModel(const QVector<ToolFactory *> &plugins, QObject *parent)
+    : QAbstractTableModel(parent)
+    , m_tools(plugins)
 {
 }
 
@@ -39,52 +39,46 @@ ToolPluginModel::~ToolPluginModel()
 {
 }
 
-int ToolPluginModel::columnCount(const QModelIndex& parent) const
+int ToolPluginModel::columnCount(const QModelIndex &parent) const
 {
-  Q_UNUSED(parent);
-  return 3;
+    Q_UNUSED(parent);
+    return 2;
 }
 
-int ToolPluginModel::rowCount(const QModelIndex& parent) const
+int ToolPluginModel::rowCount(const QModelIndex &parent) const
 {
-  Q_UNUSED(parent);
-  return m_tools.size();
+    Q_UNUSED(parent);
+    return m_tools.size();
 }
 
-QVariant ToolPluginModel::data(const QModelIndex& index, int role) const
+QVariant ToolPluginModel::data(const QModelIndex &index, int role) const
 {
-  if (!index.isValid()) {
-    return QVariant();
-  }
+    if (!index.isValid())
+        return QVariant();
 
-  const int row = index.row();
-  const int column = index.column();
-  if (role == Qt::DisplayRole) {
-    ToolFactory *factory = m_tools[row];
-    switch (column) {
-    case 0:
-      return factory->id();
-    case 1:
-      return factory->name();
-    case 2:
-      return factory->supportedTypes().join(QStringLiteral(", "));
+    const int row = index.row();
+    const int column = index.column();
+    if (role == Qt::DisplayRole) {
+        ToolFactory *factory = m_tools[row];
+        switch (column) {
+        case 0:
+            return factory->id();
+        case 1:
+            return factory->supportedTypesString();
+        }
     }
-  }
-  return QVariant();
+    return QVariant();
 }
 
 QVariant ToolPluginModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
-  if (role == Qt::DisplayRole && orientation == Qt::Horizontal) {
-    switch (section) {
-    case 0:
-      return tr("Id");
-    case 1:
-      return tr("Name");
-    case 2:
-      return tr("Supported types");
+    if (role == Qt::DisplayRole && orientation == Qt::Horizontal) {
+        switch (section) {
+        case 0:
+            return tr("Id");
+        case 1:
+            return tr("Supported types");
+        }
     }
-  }
-  return QAbstractTableModel::headerData(section, orientation, role);
+    return QAbstractTableModel::headerData(section, orientation, role);
 }
-
