@@ -2,9 +2,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -28,32 +33,31 @@
 #include <QVector>
 
 namespace GammaRay {
-
 class LocaleDataAccessorRegistry;
 struct LocaleDataAccessor;
 
 class LocaleAccessorModel : public QAbstractTableModel
 {
-  Q_OBJECT
-  Q_ENUMS(CustomRoles)
-  public:
+    Q_OBJECT
+    Q_ENUMS(CustomRoles)
+public:
     enum CustomRoles {
-      AccessorRole = UserRole + 1
+        AccessorRole = UserRole + 1
     };
 
     explicit LocaleAccessorModel(LocaleDataAccessorRegistry *registry, QObject *parent = 0);
 
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const;
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-    virtual Qt::ItemFlags flags(const QModelIndex &index) const;
-    virtual bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
+    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    bool setData(const QModelIndex &index, const QVariant &value,
+                 int role = Qt::EditRole) Q_DECL_OVERRIDE;
 
-  private:
-    QVector<LocaleDataAccessor*> enabledAccessors;
+private:
+    QVector<LocaleDataAccessor *> enabledAccessors;
     LocaleDataAccessorRegistry *m_registry;
 };
-
 }
 
 #endif
