@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,31 +37,30 @@
 #include <QVector>
 
 namespace GammaRay {
-
 struct DebugMessage {
-  QtMsgType type;
-  QString message;
-  QTime time;
-  Backtrace backtrace;
+    QtMsgType type;
+    QString message;
+    QTime time;
+    Backtrace backtrace;
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-  const char *category;
-  const char *file;
-  const char *function;
-  int line;
+    QString category;
+    QString file;
+    QString function;
+    int line;
 #endif
 };
-
 }
 
 Q_DECLARE_METATYPE(GammaRay::DebugMessage)
-Q_DECLARE_TYPEINFO(GammaRay::DebugMessage, Q_MOVABLE_TYPE);
+QT_BEGIN_NAMESPACE
+    Q_DECLARE_TYPEINFO(GammaRay::DebugMessage, Q_MOVABLE_TYPE);
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class MessageModel : public QAbstractTableModel
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit MessageModel(QObject *parent = 0);
     ~MessageModel();
 
@@ -71,13 +70,12 @@ class MessageModel : public QAbstractTableModel
     QVariant headerData(int section, Qt::Orientation orientation,
                         int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 
-  public slots:
+public slots:
     void addMessage(const GammaRay::DebugMessage &message);
 
-  private:
+private:
     QVector<DebugMessage> m_messages;
 };
-
 }
 
 #endif // MESSAGEMODEL_H
