@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -31,40 +31,47 @@
 
 #include "toolfactory.h"
 
+QT_BEGIN_NAMESPACE
+class QAbstractProxyModel;
 class QItemSelection;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class PropertyController;
 
 class MetaObjectBrowser : public QObject
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     explicit MetaObjectBrowser(ProbeInterface *probe, QObject *parent = 0);
 
-  private Q_SLOTS:
+private Q_SLOTS:
     void objectSelected(const QItemSelection &selection);
+    void objectSelected(QObject *obj);
+    void objectSelected(void *obj, const QString &typeName);
 
-  private:
-     PropertyController *m_propertyController;
+private:
+    void metaObjectSelected(const QMetaObject *mo);
+
+    PropertyController *m_propertyController;
+    QAbstractProxyModel *m_model;
 };
 
 class MetaObjectBrowserFactory : public QObject,
     public StandardToolFactory<QObject, MetaObjectBrowser>
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::ToolFactory)
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::ToolFactory)
 
-  public:
-    explicit MetaObjectBrowserFactory(QObject *parent) : QObject(parent)
+public:
+    explicit MetaObjectBrowserFactory(QObject *parent)
+        : QObject(parent)
     {
     }
 
-    QString name() const Q_DECL_OVERRIDE;
+    QVector<QByteArray> selectableTypes() const Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_METAOBJECTBROWSER_METATYPEBROWSER_H
