@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,23 +32,21 @@
 #include "propertycontrollerextension.h"
 
 namespace GammaRay {
-
 class PropertyController;
 class ObjectEnumModel;
 
 class EnumsExtension : public PropertyControllerExtension
 {
-  public:
+public:
     explicit EnumsExtension(PropertyController *controller);
     ~EnumsExtension();
 
-    bool setQObject(QObject *object);
-    bool setMetaObject(const QMetaObject *metaObject);
+    bool setQObject(QObject *object) Q_DECL_OVERRIDE;
+    bool setMetaObject(const QMetaObject *metaObject) Q_DECL_OVERRIDE;
 
-  private:
+private:
     ObjectEnumModel *m_model;
 };
-
 }
 
 #endif // ENUMSEXTENSION_H
