@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -37,12 +37,13 @@
 
 using namespace GammaRay;
 
-PropertiesExtension::PropertiesExtension(PropertyController *controller) :
-  PropertiesExtensionInterface(controller->objectBaseName() + ".propertiesExtension", controller),
-  PropertyControllerExtension(controller->objectBaseName() + ".properties"),
-  m_aggregatedPropertyModel(new AggregatedPropertyModel(this))
+PropertiesExtension::PropertiesExtension(PropertyController *controller)
+    : PropertiesExtensionInterface(controller->objectBaseName() + ".propertiesExtension",
+                                   controller)
+    , PropertyControllerExtension(controller->objectBaseName() + ".properties")
+    , m_aggregatedPropertyModel(new AggregatedPropertyModel(this))
 {
-  controller->registerModel(m_aggregatedPropertyModel, QStringLiteral("properties"));
+    controller->registerModel(m_aggregatedPropertyModel, QStringLiteral("properties"));
 }
 
 PropertiesExtension::~PropertiesExtension()
@@ -51,49 +52,36 @@ PropertiesExtension::~PropertiesExtension()
 
 bool PropertiesExtension::setQObject(QObject *object)
 {
-  if (m_object == object)
+    if (m_object == object)
+        return true;
+    m_object = object;
+    m_aggregatedPropertyModel->setObject(object);
+    setCanAddProperty(true);
+    setHasPropertyValues(true);
     return true;
-  m_object = object;
-  m_aggregatedPropertyModel->setObject(object);
-  setCanAddProperty(true);
-  setHasPropertyValues(true);
-  return true;
 }
 
 bool PropertiesExtension::setObject(void *object, const QString &typeName)
 {
-  m_object = 0;
-  m_aggregatedPropertyModel->setObject(ObjectInstance(object, typeName.toUtf8()));
-  setCanAddProperty(false);
-  setHasPropertyValues(true);
-  return true;
+    m_object = 0;
+    m_aggregatedPropertyModel->setObject(ObjectInstance(object, typeName.toUtf8()));
+    setCanAddProperty(false);
+    setHasPropertyValues(true);
+    return true;
 }
 
-bool PropertiesExtension::setMetaObject(const QMetaObject* metaObject)
+bool PropertiesExtension::setMetaObject(const QMetaObject *metaObject)
 {
-  m_object = 0;
-  m_aggregatedPropertyModel->setObject(ObjectInstance(0, metaObject));
-  setCanAddProperty(false);
-  setHasPropertyValues(false);
-  return true;
-}
-
-void PropertiesExtension::navigateToValue(int modelRow)
-{
-  QModelIndex index = m_aggregatedPropertyModel->index(modelRow, 2);
-  QVariant propertyValue = index.data(PropertyModel::ValueRole);
-  if (propertyValue.canConvert<QObject*>()) {
-    Probe::instance()->selectObject(propertyValue.value<QObject*>());
-  } else {
-    Probe::instance()->selectObject(*reinterpret_cast<void**>(propertyValue.data()),
-                                    index.data(Qt::DisplayRole).toString());
-  }
+    m_object = 0;
+    m_aggregatedPropertyModel->setObject(ObjectInstance(0, metaObject));
+    setCanAddProperty(false);
+    setHasPropertyValues(false);
+    return true;
 }
 
 void PropertiesExtension::setProperty(const QString &name, const QVariant &value)
 {
-  if (!m_object) {
-    return;
-  }
-  m_object->setProperty(name.toUtf8(), value);
+    if (!m_object)
+        return;
+    m_object->setProperty(name.toUtf8(), value);
 }
