@@ -59,10 +59,25 @@ using namespace GammaRay;
 namespace GammaRay {
 struct VariantHandlerRepository
 {
+    ~VariantHandlerRepository();
+    void clear();
+
     QHash<int, VariantHandler::Converter<QString> *> stringConverters;
     QVector<VariantHandler::GenericStringConverter> genericStringConverters;
 };
 
+VariantHandlerRepository::~VariantHandlerRepository()
+{
+    qDeleteAll(stringConverters);
+}
+
+void VariantHandlerRepository::clear()
+{
+    qDeleteAll(stringConverters);
+    stringConverters.clear();
+    genericStringConverters.clear();
+}
+
 static QString displayMatrix4x4(const QMatrix4x4 &matrix)
 {
     QStringList rows;
@@ -406,6 +421,7 @@ QVariant VariantHandler::decoration(const QVariant &value)
 
 void VariantHandler::registerStringConverter(int type, Converter<QString> *converter)
 {
+    Q_ASSERT(!s_variantHandlerRepository()->stringConverters.contains(type));
     s_variantHandlerRepository()->stringConverters.insert(type, converter);
 }
 
@@ -426,3 +442,8 @@ QVariant VariantHandler::serializableVariant(const QVariant &value)
 
     return value;
 }
+
+void VariantHandler::clear()
+{
+    s_variantHandlerRepository()->clear();
+}
