@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -33,30 +33,31 @@
 
 #include <QProcess>
 
+QT_BEGIN_NAMESPACE
 class QUrl;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 /** Launching/monitoring of the GammaRay client for out-of-process use. */
 class GAMMARAY_LAUNCHER_EXPORT ClientLauncher
 {
 public:
-  ClientLauncher();
-  ~ClientLauncher();
+    ClientLauncher();
+    ~ClientLauncher();
 
-  bool launch(const QUrl &url);
-  void terminate();
-  void waitForFinished();
+    bool launch(const QUrl &url);
+    void terminate();
+    void waitForFinished();
 
-  static void launchDetached(const QUrl &url);
+    static void launchDetached(const QUrl &url);
 
 private:
-  Q_DISABLE_COPY(ClientLauncher)
-  static QString clientPath();
-  static QStringList makeArgs(const QUrl &url);
+    Q_DISABLE_COPY(ClientLauncher)
+    static QString clientPath();
+    static QStringList makeArgs(const QUrl &url);
 
 private:
-  QProcess m_process;
+    QProcess m_process;
 };
 }
 
