@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,23 +32,23 @@
 #include "injector/debuggerinjector.h"
 
 namespace GammaRay {
-
 class LldbInjector : public DebuggerInjector
 {
-  Q_OBJECT
-  public:
-    LldbInjector();
-    ~LldbInjector();
-
+    Q_OBJECT
+public:
+    explicit LldbInjector(const QString &executableOverride = QString());
+    bool selfTest() Q_DECL_OVERRIDE;
     QString name() const Q_DECL_OVERRIDE;
-    bool launch(const QStringList& programAndArgs, const QString& probeDll, const QString& probeFunc, const QProcessEnvironment &env) Q_DECL_OVERRIDE;
-    bool attach(int pid, const QString& probeDll, const QString& probeFunc) Q_DECL_OVERRIDE;
+    bool launch(const QStringList &programAndArgs, const QString &probeDll,
+                const QString &probeFunc, const QProcessEnvironment &env) Q_DECL_OVERRIDE;
+    bool attach(int pid, const QString &probeDll, const QString &probeFunc) Q_DECL_OVERRIDE;
 
-  protected:
-    QString debuggerExecutable() const Q_DECL_OVERRIDE;
-    void execCmd(const QByteArray& cmd, bool waitForWritten = true) Q_DECL_OVERRIDE;
-    void addFunctionBreakpoint(const QByteArray& function) Q_DECL_OVERRIDE;
-    void addMethodBreakpoint(const QByteArray& method) Q_DECL_OVERRIDE;
+protected:
+    void disableConfirmations() Q_DECL_OVERRIDE;
+    void addFunctionBreakpoint(const QByteArray &function) Q_DECL_OVERRIDE;
+    void addMethodBreakpoint(const QByteArray &method) Q_DECL_OVERRIDE;
+    void clearBreakpoints() Q_DECL_OVERRIDE;
+    void printBacktrace() Q_DECL_OVERRIDE;
 };
 }
 
