@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -29,15 +29,18 @@
 
 #if !defined Q_OS_WIN && !defined Q_OS_MAC
 
+#include <QCoreApplication>
 #include <QString>
 
+namespace GammaRay {
 /**
  * This class checks if it's possible to overwrite symbols
  * by setting the LD_PRELOAD environment variable
  */
 class PreloadCheck
 {
-  public:
+    Q_DECLARE_TR_FUNCTIONS(GammaRay::PreloadCheck)
+public:
     PreloadCheck();
 
     /**
@@ -54,10 +57,10 @@ class PreloadCheck
 
     QString errorString() const;
 
-  protected:
+protected:
     void setErrorString(const QString &err);
 
-  private:
+private:
     /**
      * Additional method for testing whether the call to the function will go
      * through .got and lazy binding stub (MIPS specific)
@@ -68,6 +71,7 @@ class PreloadCheck
 
     QString m_errorString;
 };
+}
 
 #endif
 
