@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -26,19 +26,17 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
 #include "processinjector.h"
 
 #include <QDebug>
 #include <iostream>
 
-
 using namespace GammaRay;
 
-ProcessInjector::ProcessInjector() :
-  mExitCode(-1),
-  mProcessError(QProcess::UnknownError),
-  mExitStatus(QProcess::NormalExit)
+ProcessInjector::ProcessInjector()
+    : mExitCode(-1)
+    , mProcessError(QProcess::UnknownError)
+    , mExitStatus(QProcess::NormalExit)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     m_proc.setInputChannelMode(QProcess::ForwardedInputChannel);
@@ -60,38 +58,40 @@ void ProcessInjector::stop()
         m_proc.kill(); // kill it softly
 }
 
-bool ProcessInjector::launchProcess(const QStringList& programAndArgs, const QProcessEnvironment& env)
+bool ProcessInjector::launchProcess(const QStringList &programAndArgs,
+                                    const QProcessEnvironment &env)
 {
-  m_proc.setProcessEnvironment(env);
+    m_proc.setWorkingDirectory(workingDirectory());
+    m_proc.setProcessEnvironment(env);
 
-  QStringList args = programAndArgs;
+    QStringList args = programAndArgs;
 
-  if (!env.value(QStringLiteral("GAMMARAY_TARGET_WRAPPER")).isEmpty()) {
-    const QString fullWrapperCmd = env.value(QStringLiteral("GAMMARAY_TARGET_WRAPPER"));
-    // ### TODO properly handle quoted arguments!
-    QStringList newArgs = fullWrapperCmd.split(' ');
-    newArgs += args;
-    args = newArgs;
-    qDebug() << "Launching with target wrapper:" << args;
-  } else if (env.value(QStringLiteral("GAMMARAY_GDB")).toInt()) {
-    QStringList newArgs;
-    newArgs << QStringLiteral("gdb");
+    if (!env.value(QStringLiteral("GAMMARAY_TARGET_WRAPPER")).isEmpty()) {
+        const QString fullWrapperCmd = env.value(QStringLiteral("GAMMARAY_TARGET_WRAPPER"));
+        // ### TODO properly handle quoted arguments!
+        QStringList newArgs = fullWrapperCmd.split(' ');
+        newArgs += args;
+        args = newArgs;
+        qDebug() << "Launching with target wrapper:" << args;
+    } else if (env.value(QStringLiteral("GAMMARAY_GDB")).toInt()) {
+        QStringList newArgs;
+        newArgs << QStringLiteral("gdb");
 #ifndef Q_OS_MAC
-    newArgs << QStringLiteral("--eval-command") << QStringLiteral("run");
+        newArgs << QStringLiteral("--eval-command") << QStringLiteral("run");
 #endif
-    newArgs << QStringLiteral("--args");
-    newArgs += args;
-    args = newArgs;
-  }
+        newArgs << QStringLiteral("--args");
+        newArgs += args;
+        args = newArgs;
+    }
 
-  const QString program = args.takeFirst();
-  m_proc.start(program, args);
+    const QString program = args.takeFirst();
+    m_proc.start(program, args);
 
-  bool ret = m_proc.waitForStarted(-1);
-  if (ret)
-    emit started();
+    bool ret = m_proc.waitForStarted(-1);
+    if (ret)
+        emit started();
 
-  return ret;
+    return ret;
 }
 
 void ProcessInjector::processFailed()
@@ -106,43 +106,43 @@ void ProcessInjector::processFinished()
     mExitStatus = m_proc.exitStatus();
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-    if (mProcessError == QProcess::FailedToStart) {
-      mErrorString.prepend(QStringLiteral("Could not start '%1': ").arg(m_proc.program()));
-    }
+    if (mProcessError == QProcess::FailedToStart)
+        mErrorString.prepend(QStringLiteral("Could not start '%1': ").arg(m_proc.program()));
+
 #endif
     emit finished();
 }
 
 int ProcessInjector::exitCode()
 {
-  return mExitCode;
+    return mExitCode;
 }
 
 QProcess::ExitStatus ProcessInjector::exitStatus()
 {
-  return mExitStatus;
+    return mExitStatus;
 }
 
 QProcess::ProcessError ProcessInjector::processError()
 {
-  return mProcessError;
+    return mProcessError;
 }
 
 QString ProcessInjector::errorString()
 {
-  return mErrorString;
+    return mErrorString;
 }
 
 void ProcessInjector::readStdErr()
 {
-  QString error = m_proc.readAllStandardError();
-  std::cerr << qPrintable(error);
-  emit stderrMessage(error);
+    QString error = m_proc.readAllStandardError();
+    std::cerr << qPrintable(error);
+    emit stderrMessage(error);
 }
 
 void ProcessInjector::readStdOut()
 {
-  QString message = m_proc.readAllStandardOutput();
-  std::cout << qPrintable(message);
-  emit stdoutMessage(message);
+    QString message = m_proc.readAllStandardOutput();
+    std::cout << qPrintable(message);
+    emit stdoutMessage(message);
 }
