@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -31,35 +31,46 @@
 
 #include "gammaray_launcher_export.h"
 
+#include <QStringList>
 #include <QVector>
 
+QT_BEGIN_NAMESPACE
 class QString;
-class QStringList;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class ProbeABI;
 
+/** @brief Functions to locate a suitable probe. */
 namespace ProbeFinder {
+/**
+ * Attempts to find the full path of the probe DLL.
+ *
+ * @deprecated Use the findProbe() overload below.
+ */
+GAMMARAY_LAUNCHER_DEPRECATED_EXPORT QString findProbe(const QString &baseName,
+                                                      const ProbeABI &probeAbi);
 
-  /**
-   * Attempts to find the full path of the probe DLL.
-   */
-  GAMMARAY_LAUNCHER_EXPORT QString findProbe(const QString& baseName, const ProbeABI& probeAbi);
+/**
+ * Attempts to find the full path of the probe DLL with ABI @p probeAbi, considering
+ * the additional search paths @p searchRoots.
+ */
+GAMMARAY_LAUNCHER_EXPORT QString findProbe(const ProbeABI &probeAbi,
+                                           const QStringList &searchRoots = QStringList());
 
-  /**
-   * Find the best matching probe for the given @p targetABI.
-   * An invalid ProbeABI instance is returned if there is no compatible probe installed.
-   */
-  GAMMARAY_LAUNCHER_EXPORT ProbeABI findBestMatchingABI(const ProbeABI &targetABI);
-  GAMMARAY_LAUNCHER_EXPORT ProbeABI findBestMatchingABI(const ProbeABI &targetABI, const QVector<ProbeABI> &availableABIs);
+/**
+ * Find the best matching probe for the given @p targetABI.
+ * An invalid ProbeABI instance is returned if there is no compatible probe installed.
+ */
+GAMMARAY_LAUNCHER_EXPORT ProbeABI findBestMatchingABI(const ProbeABI &targetABI);
+GAMMARAY_LAUNCHER_EXPORT ProbeABI findBestMatchingABI(const ProbeABI &targetABI,
+                                                      const QVector<ProbeABI> &availableABIs);
 
-  /**
-   * List all available probe ABIs.
-   */
-  GAMMARAY_LAUNCHER_EXPORT QVector<ProbeABI> listProbeABIs();
+/**
+ * List all available probe ABIs.
+ */
+GAMMARAY_LAUNCHER_EXPORT QVector<ProbeABI> listProbeABIs();
 }
-
 }
 
 #endif // GAMMARAY_PROBEFINDER_H
