@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -30,7 +35,6 @@
 #include "ui_attachdialog.h"
 
 namespace GammaRay {
-
 class LaunchOptions;
 class ProcessModel;
 class ProcessFilterModel;
@@ -38,9 +42,9 @@ class ProbeABIModel;
 
 class AttachDialog : public QWidget
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     explicit AttachDialog(QWidget *parent = 0, Qt::WindowFlags f = 0);
 
     LaunchOptions launchOptions() const;
@@ -50,23 +54,21 @@ class AttachDialog : public QWidget
     bool isValid() const;
     void writeSettings();
 
-  signals:
+signals:
     void updateButtonState();
     void activate();
 
-  private slots:
+private slots:
     void updateProcesses();
     void updateProcessesFinished();
     void selectABI(const QModelIndex &processIndex);
 
-  private:
+private:
     Ui::AttachDialog ui;
     ProcessModel *m_model;
     ProcessFilterModel *m_proxyModel;
-    QTimer *m_timer;
     ProbeABIModel *m_abiModel;
 };
-
 } // namespace GammaRay
 
 #endif // ATTACHDIALOG_H
