@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,7 +32,6 @@
 #include <QWidget>
 
 namespace GammaRay {
-
 namespace Ui {
 class ConnectPage;
 }
@@ -35,26 +39,26 @@ class ConnectPage;
 /** UI for connecting to a running GammaRay instance. */
 class ConnectPage : public QWidget
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
-  explicit ConnectPage(QWidget* parent = 0);
-  ~ConnectPage();
+    explicit ConnectPage(QWidget *parent = 0);
+    ~ConnectPage();
 
-  bool isValid() const;
-  void writeSettings();
+    bool isValid() const;
+    void writeSettings();
 
 public slots:
-  void launchClient();
+    void launchClient();
 
 signals:
-  void updateButtonState();
+    void updateButtonState();
+    void activate();
 
 private slots:
-  void instanceSelected();
+    void instanceSelected();
 
 private:
-  QScopedPointer<Ui::ConnectPage> ui;
-
+    QScopedPointer<Ui::ConnectPage> ui;
 };
 }
 
