@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,31 +32,30 @@
 #include <QDialog>
 
 namespace GammaRay {
-
 class LaunchOptions;
 namespace Ui {
-  class LauncherWindow;
+class LauncherWindow;
 }
 
 class LauncherWindow : public QDialog
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit LauncherWindow(QWidget *parent = 0);
     ~LauncherWindow();
 
     /// returns all information required to perform the launch/attach
     LaunchOptions launchOptions() const;
 
-    void accept();
+    void accept() Q_DECL_OVERRIDE;
 
-  private slots:
+private slots:
     void tabChanged();
+    void help();
 
-  private:
+private:
     Ui::LauncherWindow *ui;
 };
-
 }
 
 #endif // GAMMARAY_LAUNCHERWINDOW_H
