@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -31,7 +31,8 @@
 #include "launchoptions.h"
 #include "launcherfinder.h"
 
-#include "common/paths.h"
+#include <common/paths.h>
+#include <common/translator.h>
 
 #include <QApplication>
 
@@ -39,23 +40,23 @@ using namespace GammaRay;
 
 int main(int argc, char **argv)
 {
-  QCoreApplication::setOrganizationName(QStringLiteral("KDAB"));
-  QCoreApplication::setOrganizationDomain(QStringLiteral("kdab.com"));
-  QCoreApplication::setApplicationName(QStringLiteral("GammaRay"));
+    QCoreApplication::setOrganizationName(QStringLiteral("KDAB"));
+    QCoreApplication::setOrganizationDomain(QStringLiteral("kdab.com"));
+    QCoreApplication::setApplicationName(QStringLiteral("GammaRay"));
 
-  QApplication app(argc, argv);
-  Paths::setRelativeRootPath(GAMMARAY_INVERSE_LIBEXEC_DIR);
+    QApplication app(argc, argv);
+    Paths::setRelativeRootPath(GAMMARAY_INVERSE_LIBEXEC_DIR);
+    Translator::loadStandAloneTranslations();
 
-  LauncherWindow launcher;
-  launcher.show();
-  const int result = app.exec();
+    LauncherWindow launcher;
+    launcher.show();
+    const int result = app.exec();
 
-  if (launcher.result() == QDialog::Accepted) {
-    const LaunchOptions opts = launcher.launchOptions();
-    if (opts.isValid()) {
-      opts.execute(LauncherFinder::findLauncher(LauncherFinder::Injector));
+    if (launcher.result() == QDialog::Accepted) {
+        const LaunchOptions opts = launcher.launchOptions();
+        if (opts.isValid())
+            opts.execute(LauncherFinder::findLauncher(LauncherFinder::Injector));
     }
-  }
 
-  return result;
+    return result;
 }
