@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,24 +32,22 @@
 #include <QLabel>
 
 namespace GammaRay {
-
 class PromoLabel : public QLabel
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     explicit PromoLabel(QWidget *parent = 0, Qt::WindowFlags f = 0);
 
     static QImage tintedImage(const QString &image, const QColor &color);
 
-  protected:
-    virtual bool event(QEvent *e);
-    virtual void mouseReleaseEvent(QMouseEvent *ev);
+protected:
+    bool event(QEvent *e) Q_DECL_OVERRIDE;
+    void mouseReleaseEvent(QMouseEvent *ev) Q_DECL_OVERRIDE;
 
-  private:
+private:
     void updatePixmap();
 };
-
 }
 
 #endif // PROMOLABEL_H
