@@ -34,10 +34,16 @@
 #include <ui/tooluifactory.h>
 
 QT_BEGIN_NAMESPACE
+class QItemSelection;
 class QModelIndex;
 QT_END_NAMESPACE
 
 namespace GammaRay {
+
+namespace Ui {
+class ActionInspectorWidget;
+}
+
 class ActionInspectorWidget : public QWidget
 {
     Q_OBJECT
@@ -48,8 +54,11 @@ public:
 
 private Q_SLOTS:
     void triggerAction(const QModelIndex &index);
+    void contextMenu(QPoint pos);
+    void selectionChanged(const QItemSelection &selection);
 
 private:
+    QScopedPointer<Ui::ActionInspectorWidget> ui;
     UIStateManager m_stateManager;
 };
 
