@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -24,37 +29,37 @@
 #ifndef GAMMARAY_CODECBROWSERWIDGET_CODECBROWSERWIDGET_H
 #define GAMMARAY_CODECBROWSERWIDGET_CODECBROWSERWIDGET_H
 
+#include <ui/uistatemanager.h>
 #include <ui/tooluifactory.h>
 
 #include <QWidget>
 
 namespace GammaRay {
-
 namespace Ui {
-  class CodecBrowserWidget;
+class CodecBrowserWidget;
 }
 
 class CodecBrowserWidget : public QWidget
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit CodecBrowserWidget(QWidget *parent = 0);
     ~CodecBrowserWidget();
 
-  private slots:
+private slots:
     void textChanged(const QString &text);
 
-  private:
+private:
     QScopedPointer<Ui::CodecBrowserWidget> ui;
+    UIStateManager m_stateManager;
 };
 
 class CodecBrowserUiFactory : public QObject, public StandardToolUiFactory<CodecBrowserWidget>
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::ToolUiFactory)
-  Q_PLUGIN_METADATA(IID "com.kdab.gammaray.CodecBrowserUi")
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::ToolUiFactory)
+    Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolUiFactory" FILE "gammaray_codecbrowser.json")
 };
-
 }
 
 #endif // GAMMARAY_CODECBROWSERWIDGET_H
