@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -26,18 +31,19 @@
 
 #include <QObject>
 
+QT_BEGIN_NAMESPACE
 class QColor;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class FontBrowserInterface : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit FontBrowserInterface(QObject *parent);
     virtual ~FontBrowserInterface();
 
-  public slots:
+public slots:
     virtual void updateText(const QString &text) = 0;
     virtual void toggleBoldFont(bool bold) = 0;
     virtual void toggleItalicFont(bool italic) = 0;
@@ -45,9 +51,10 @@ class FontBrowserInterface : public QObject
     virtual void setPointSize(int size) = 0;
     virtual void setColors(const QColor &foreground, const QColor &background) = 0;
 };
-
 }
 
+QT_BEGIN_NAMESPACE
 Q_DECLARE_INTERFACE(GammaRay::FontBrowserInterface, "com.kdab.GammaRay.FontBrowser")
+QT_END_NAMESPACE
 
 #endif // FONTBROWSERINTERFACE_H
