@@ -2,9 +2,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -24,32 +29,32 @@
 
 #include <QToolBar>
 
+QT_BEGIN_NAMESPACE
 class QComboBox;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class VtkWidget;
 
 class VtkPanel : public QToolBar
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     explicit VtkPanel(VtkWidget *vtkWidget, QWidget *parent = 0);
     virtual ~VtkPanel();
 
-  public slots:
-     void layoutChanged(int);
-     void stereoModeChanged(int);
+public slots:
+    void layoutChanged(int);
+    void stereoModeChanged(int);
 
-  private:
+private:
     VtkWidget *m_vtkWidget;
 
     QComboBox *m_layoutBox;
     QComboBox *m_stereoBox;
     QString m_currentLayout;
 };
-
 }
 
 #endif // GAMMARAY_VTKPANEL_H
