@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -36,12 +36,12 @@
 using namespace GammaRay;
 
 SGGeometryExtension::SGGeometryExtension(PropertyController *controller)
-  : SGGeometryExtensionInterface(controller->objectBaseName() + ".sgGeometry", controller),
-    PropertyControllerExtension(controller->objectBaseName() + ".sgGeometry"),
-    m_node(0),
-    m_model(new SGGeometryModel(this))
+    : SGGeometryExtensionInterface(controller->objectBaseName() + ".sgGeometry", controller)
+    , PropertyControllerExtension(controller->objectBaseName() + ".sgGeometry")
+    , m_node(0)
+    , m_model(new SGGeometryModel(this))
 {
-  controller->registerModel(m_model, QStringLiteral("sgGeometryModel"));
+    controller->registerModel(m_model, QStringLiteral("sgGeometryModel"));
 }
 
 SGGeometryExtension::~SGGeometryExtension()
@@ -50,17 +50,17 @@ SGGeometryExtension::~SGGeometryExtension()
 
 bool SGGeometryExtension::setObject(void *object, const QString &typeName)
 {
-  if (typeName == QStringLiteral("QSGGeometryNode")) {
-    m_node = static_cast<QSGGeometryNode*>(object);
-    m_model->setNode(m_node);
+    if (typeName == QStringLiteral("QSGGeometryNode")) {
+        m_node = static_cast<QSGGeometryNode *>(object);
+        m_model->setNode(m_node);
 
-    QSGGeometry *geometry = m_node->geometry();
-    emit geometryChanged(
-      geometry->drawingMode(),
-      QByteArray::fromRawData(reinterpret_cast<char*>(geometry->indexData()),
-                              geometry->indexCount() * geometry->sizeOfIndex()),
-      geometry->indexType());
-    return true;
-  }
-  return false;
+        QSGGeometry *geometry = m_node->geometry();
+        emit geometryChanged(
+            geometry->drawingMode(),
+            QByteArray::fromRawData(reinterpret_cast<char *>(geometry->indexData()),
+                                    geometry->indexCount() * geometry->sizeOfIndex()),
+            geometry->indexType());
+        return true;
+    }
+    return false;
 }
