@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,27 +32,27 @@
 #include <QObject>
 
 namespace GammaRay {
-
 /** @brief Client/Server interface of the sggeometry viewer. */
 class SGGeometryExtensionInterface : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit SGGeometryExtensionInterface(const QString &name, QObject *parent = 0);
     virtual ~SGGeometryExtensionInterface();
 
     const QString &name() const;
 
-  signals:
+signals:
     void geometryChanged(uint drawingMode, const QByteArray &indices, int indexType);
 
-  private:
+private:
     QString m_name;
 };
-
 }
 
+QT_BEGIN_NAMESPACE
 Q_DECLARE_INTERFACE(GammaRay::SGGeometryExtensionInterface,
                     "com.kdab.GammaRay.SGGeometryExtensionInterface")
+QT_END_NAMESPACE
 
 #endif // GAMMARAY_SGGEOMETRYEXTENSIONINTERFACE_H
