@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,19 +32,20 @@
 #include <QWidget>
 #include <qopengl.h>
 
+QT_BEGIN_NAMESPACE
 class QItemSelection;
 class QPainter;
 class QItemSelectionModel;
 class QAbstractItemModel;
 class QModelIndex;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class SGWireframeWidget : public QWidget
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     explicit SGWireframeWidget(QWidget *parent = 0, Qt::WindowFlags f = 0);
     ~SGWireframeWidget();
 
@@ -52,22 +53,22 @@ class SGWireframeWidget : public QWidget
     void setModel(QAbstractItemModel *m_model);
     void setHighlightModel(QItemSelectionModel *selectionModel);
 
-  public slots:
+public slots:
     void onGeometryChanged(uint drawingMode, const QByteArray &indexData, int indexType);
 
-  protected:
-    void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QMouseEvent*) Q_DECL_OVERRIDE;
+protected:
+    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+    void mouseReleaseEvent(QMouseEvent *) Q_DECL_OVERRIDE;
 
-  private slots:
+private slots:
     void onModelDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
     void onHighlightDataChanged(const QItemSelection &selected, const QItemSelection &deselected);
 
-  private:
+private:
     void drawWire(QPainter *painter, int vertexIndex1, int vertexIndex2);
     void drawHighlightedFace(QPainter *painter, const QVector<int> &vertexIndices);
 
-  private:
+private:
     QAbstractItemModel *m_model;
     int m_positionColumn;
     GLenum m_drawingMode;
@@ -81,7 +82,6 @@ class SGWireframeWidget : public QWidget
     qreal m_zoom;
     const QPointF m_offset;
 };
-
 }
 
 #endif // SGWIREFRAMEWIDGET_H
