@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,20 +32,18 @@
 #include "materialextensioninterface.h"
 
 namespace GammaRay {
-
 class MaterialExtensionClient : public MaterialExtensionInterface
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::MaterialExtensionInterface)
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::MaterialExtensionInterface)
 
-  public:
+public:
     explicit MaterialExtensionClient(const QString &name, QObject *parent = 0);
     virtual ~MaterialExtensionClient();
 
-  public slots:
-    void getShader(const QString &fileName);
+public slots:
+    void getShader(const QString &fileName) Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_MATERIALEXTENSIONCLIENT_H
