@@ -35,6 +35,7 @@
 
 #include <common/modelevent.h>
 #include <common/objectbroker.h>
+#include <common/probecontrollerinterface.h>
 #include <common/remoteviewframe.h>
 
 #include <core/metaobject.h>
@@ -220,6 +221,17 @@ static QString qsgTextureWrapModeToString(QSGTexture::WrapMode wrapMode)
     return QStringLiteral("Unknown: %1").arg(wrapMode);
 }
 
+static bool isGoodCandidateItem(QQuickItem *item)
+{
+    if (!item->isVisible() || item->z() < 0 || qFuzzyCompare(item->opacity() + 1.0, qreal(1.0)) ||
+            !item->flags().testFlag(QQuickItem::ItemHasContents) ||
+            item->metaObject() == &QQuickItem::staticMetaObject) {
+        return false;
+    }
+
+    return true;
+}
+
 QuickInspector::QuickInspector(ProbeInterface *probe, QObject *parent)
     : QuickInspectorInterface(parent)
     , m_probe(probe)
@@ -272,7 +284,9 @@ QuickInspector::QuickInspector(ProbeInterface *probe, QObject *parent)
             this, &QuickInspector::sgSelectionChanged);
     connect(m_sgModel, &QuickSceneGraphModel::nodeDeleted, this, &QuickInspector::sgNodeDeleted);
 
-    connect(m_remoteView, &RemoteViewServer::doPickElement, this, &QuickInspector::pickItemAt);
+    connect(m_remoteView, &RemoteViewServer::elementsAtRequested, this, &QuickInspector::requestElementsAt);
+    connect(this, &QuickInspector::elementsAtReceived, m_remoteView, &RemoteViewServer::elementsAtReceived);
+    connect(m_remoteView, &RemoteViewServer::doPickElementId, this, &QuickInspector::pickElementId);
     connect(m_remoteView, &RemoteViewServer::requestUpdate, this, &QuickInspector::slotGrabWindow);
 }
 
@@ -289,8 +303,13 @@ void QuickInspector::selectWindow(int index)
 
 void QuickInspector::selectWindow(QQuickWindow *window)
 {
-    if (m_window)
+    if (m_window == window) {
+        return;
+    }
+
+    if (m_window) {
         disconnect(m_window, 0, this, 0);
+    }
 
     m_window = window;
     m_itemModel->setWindow(window);
@@ -557,38 +576,76 @@ void QuickInspector::sgNodeDeleted(QSGNode *node)
         m_sgPropertyController->setObject(0);
 }
 
-void QuickInspector::pickItemAt(const QPoint &pos)
+void QuickInspector::requestElementsAt(const QPoint &pos, GammaRay::RemoteViewInterface::RequestMode mode)
 {
     if (!m_window)
         return;
-    QQuickItem *item = recursiveChiltAt(m_window->contentItem(), pos);
+
+    int bestCandidate;
+    const ObjectIds objects = recursiveItemsAt(m_window->contentItem(), pos, mode, bestCandidate);
+
+    if (!objects.isEmpty()) {
+        emit elementsAtReceived(objects, bestCandidate);
+    }
+}
+
+void QuickInspector::pickElementId(const GammaRay::ObjectId &id)
+{
+    QQuickItem *item = id.asQObjectType<QQuickItem *>();
     if (item)
         m_probe->selectObject(item);
 }
 
-QQuickItem *QuickInspector::recursiveChiltAt(QQuickItem *parent, const QPointF &pos) const
+ObjectIds QuickInspector::recursiveItemsAt(QQuickItem *parent, const QPointF &pos,
+                                           GammaRay::RemoteViewInterface::RequestMode mode, int &bestCandidate) const
 {
     Q_ASSERT(parent);
-    QQuickItem *child = Q_NULLPTR;
+    ObjectIds objects;
+
+    bestCandidate = -1;
 
-    // almost like QQItem::childAt, but with some extra filtering for better matching what you can see on screen
     const auto childItems = parent->childItems();
     for (int i = childItems.size() - 1; i >= 0; --i) { // backwards to match z order
         auto c = childItems.at(i);
         const QPointF p = parent->mapToItem(c, pos);
-        if (c->isVisible() && p.x() >= 0 && c->width() >= p.x() && p.y() >= 0
-            && c->height() >= p.y()) {
-            child = c;
-            // empty QQItems are less interesting, so continue looking for something better, very common first hits in ListViews for example
-            if (c->metaObject() == &QQuickItem::staticMetaObject && c->childItems().isEmpty())
-                continue;
+        if (c->contains(p)) {
+            const bool hasSubChildren = !c->childItems().isEmpty();
+
+            if (hasSubChildren) {
+                const int count = objects.count();
+                int bc;
+                objects << recursiveItemsAt(c, p, mode, bc);
+
+                if (bestCandidate == -1 && bc != -1 && c->z() >= 0) {
+                    bestCandidate = count + bc;
+                }
+            }
+            else {
+                if (bestCandidate == -1 && isGoodCandidateItem(c)) {
+                    bestCandidate = objects.count();
+                }
+
+                objects << ObjectId(c);
+            }
+        }
+
+        if (bestCandidate != -1 && mode == RemoteViewInterface::RequestBest) {
             break;
         }
     }
 
-    if (child)
-        return recursiveChiltAt(child, parent->mapToItem(child, pos));
-    return parent;
+    if (bestCandidate == -1 && isGoodCandidateItem(parent)) {
+        bestCandidate = objects.count();
+    }
+
+    objects << ObjectId(parent);
+
+    if (bestCandidate != -1 && mode == RemoteViewInterface::RequestBest) {
+        objects = ObjectIds() << objects[bestCandidate];
+        bestCandidate = 0;
+    }
+
+    return objects;
 }
 
 void GammaRay::QuickInspector::registerGrabWindowCallback(GrabWindowCallback callback)
@@ -599,13 +656,15 @@ void GammaRay::QuickInspector::registerGrabWindowCallback(GrabWindowCallback cal
 bool QuickInspector::eventFilter(QObject *receiver, QEvent *event)
 {
     if (event->type() == QEvent::MouseButtonRelease) {
-        QMouseEvent *mouseEv = static_cast<QMouseEvent *>(event);
-        if (mouseEv->button() == Qt::LeftButton
-            && mouseEv->modifiers() == (Qt::ControlModifier | Qt::ShiftModifier)) {
-            QQuickWindow *window = qobject_cast<QQuickWindow *>(receiver);
+        QMouseEvent *mouseEv = static_cast<QMouseEvent*>(event);
+        if (mouseEv->button() == Qt::LeftButton &&
+                mouseEv->modifiers() == (Qt::ControlModifier | Qt::ShiftModifier)) {
+            QQuickWindow *window = qobject_cast<QQuickWindow*>(receiver);
             if (window && window->contentItem()) {
-                QQuickItem *item = recursiveChiltAt(window->contentItem(), mouseEv->pos());
-                m_probe->selectObject(item);
+                int bestCandidate;
+                const ObjectIds objects = recursiveItemsAt(window->contentItem(), mouseEv->pos(),
+                                                           RemoteViewInterface::RequestBest, bestCandidate);
+                m_probe->selectObject(objects.value(bestCandidate == -1 ? 0 : bestCandidate).asQObject());
             }
         }
     }
@@ -737,7 +796,6 @@ void QuickInspector::registerVariantHandlers()
     VariantHandler::registerStringConverter<QSGOpacityNode *>(Util::addressToString);
     VariantHandler::registerStringConverter<QSGNode::Flags>(qSGNodeFlagsToString);
     VariantHandler::registerStringConverter<QSGNode::DirtyState>(qSGNodeDirtyStateToString);
-    VariantHandler::registerStringConverter<const QSGClipNode *>(Util::addressToString);
     VariantHandler::registerStringConverter<QSGGeometry *>(Util::addressToString);
     VariantHandler::registerStringConverter<const QSGGeometry *>(Util::addressToString);
     VariantHandler::registerStringConverter<QSGMaterial *>(Util::addressToString);
