@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -27,50 +27,51 @@
 */
 
 #include "quickinspectorinterface.h"
+#include "quickitemmodelroles.h"
 
 #include <common/objectbroker.h>
 
 #include <QDataStream>
 
-using namespace GammaRay;
-
+namespace GammaRay {
 QDataStream &operator<<(QDataStream &out, QuickInspectorInterface::Features value)
 {
-  out << qint32(value);
-  return out;
+    out << qint32(value);
+    return out;
 }
 
 QDataStream &operator>>(QDataStream &in, QuickInspectorInterface::Features &value)
 {
-  qint32 t;
-  in >> t;
-  value = static_cast<QuickInspectorInterface::Features>(t);
-  return in;
+    qint32 t;
+    in >> t;
+    value = static_cast<QuickInspectorInterface::Features>(t);
+    return in;
 }
 
 QDataStream &operator<<(QDataStream &out, QuickInspectorInterface::RenderMode value)
 {
-  out << qint32(value);
-  return out;
+    out << qint32(value);
+    return out;
 }
 
 QDataStream &operator>>(QDataStream &in, QuickInspectorInterface::RenderMode &value)
 {
-  qint32 t;
-  in >> t;
-  value = static_cast<QuickInspectorInterface::RenderMode>(t);
-  return in;
+    qint32 t;
+    in >> t;
+    value = static_cast<QuickInspectorInterface::RenderMode>(t);
+    return in;
 }
 
-QuickInspectorInterface::QuickInspectorInterface(QObject * parent) : QObject(parent)
+QuickInspectorInterface::QuickInspectorInterface(QObject *parent)
+    : QObject(parent)
 {
-  ObjectBroker::registerObject<QuickInspectorInterface*>(this);
-  qRegisterMetaTypeStreamOperators<Features>();
-  qRegisterMetaTypeStreamOperators<RenderMode>();
-  qRegisterMetaTypeStreamOperators<QuickItemGeometry>();
-  qRegisterMetaTypeStreamOperators<TransferImage>();
+    ObjectBroker::registerObject<QuickInspectorInterface *>(this);
+    qRegisterMetaTypeStreamOperators<Features>();
+    qRegisterMetaTypeStreamOperators<RenderMode>();
+    qRegisterMetaTypeStreamOperators<QuickItemGeometry>();
 }
 
 QuickInspectorInterface::~QuickInspectorInterface()
 {
 }
+}
