@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Anton Kreuzkamp <anton.kreuzkamp@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -32,31 +32,32 @@
 #include <QModelIndex>
 #include <QStyledItemDelegate>
 
-class QTreeView;
+QT_BEGIN_NAMESPACE
+class QAbstractItemView;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class QuickItemDelegate : public QStyledItemDelegate
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
-    explicit QuickItemDelegate(QTreeView *view);
+public:
+    explicit QuickItemDelegate(QAbstractItemView *view);
 
-  public Q_SLOTS:
+public Q_SLOTS:
     void setTextColor(const QVariant &textColor, const QPersistentModelIndex &index);
 
-  protected:
+protected:
     void paint(QPainter *painter, const QStyleOptionViewItem &option,
                const QModelIndex &index) const Q_DECL_OVERRIDE;
 
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QSize sizeHint(const QStyleOptionViewItem &option,
+                   const QModelIndex &index) const Q_DECL_OVERRIDE;
 
-  private:
+private:
     QHash<QModelIndex, QColor> m_colors;
-    QTreeView *m_view;
+    QAbstractItemView *m_view;
 };
-
 }
 
 Q_DECLARE_METATYPE(QPersistentModelIndex)
