@@ -4,7 +4,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -35,18 +35,19 @@
 #include <QPointer>
 #include <QVector>
 
+QT_BEGIN_NAMESPACE
 class QSignalMapper;
 class QQuickItem;
 class QQuickWindow;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 /** QQ2 item tree model. */
 class QuickItemModel : public ObjectModelBase<QAbstractItemModel>
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     explicit QuickItemModel(QObject *parent = 0);
     ~QuickItemModel();
 
@@ -58,16 +59,16 @@ class QuickItemModel : public ObjectModelBase<QAbstractItemModel>
     QModelIndex index(int row, int column, const QModelIndex &parent) const Q_DECL_OVERRIDE;
     QMap< int, QVariant > itemData(const QModelIndex &index) const Q_DECL_OVERRIDE;
 
-  public slots:
+public slots:
     void objectAdded(QObject *obj);
     void objectRemoved(QObject *obj);
 
-  private slots:
+private slots:
     void itemReparented();
     void itemWindowChanged();
     void itemUpdated();
 
-  private:
+private:
     friend class QuickEventMonitor;
     void updateItem(QQuickItem *item, int role);
     void recursivelyUpdateItem(QQuickItem *item);
@@ -98,24 +99,23 @@ class QuickItemModel : public ObjectModelBase<QAbstractItemModel>
 
     QPointer<QQuickWindow> m_window;
 
-    QHash<QQuickItem*, QQuickItem*> m_childParentMap;
-    QHash<QQuickItem*, QVector<QQuickItem*> > m_parentChildMap;
-    QHash<QQuickItem*, int> m_itemFlags;
+    QHash<QQuickItem *, QQuickItem *> m_childParentMap;
+    QHash<QQuickItem *, QVector<QQuickItem *> > m_parentChildMap;
+    QHash<QQuickItem *, int> m_itemFlags;
 };
 
 class QuickEventMonitor : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit QuickEventMonitor(QuickItemModel *parent);
 
-  protected:
+protected:
     bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
 
-  private:
+private:
     QuickItemModel *m_model;
 };
-
 }
 
 #endif // GAMMARAY_QUICKITEMMODEL_H
