@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -26,6 +31,7 @@
 
 #include <QObject>
 
+QT_BEGIN_NAMESPACE
 class QPainter;
 class QGraphicsItem;
 class QSize;
@@ -33,33 +39,35 @@ class QTransform;
 class QRectF;
 class QPixmap;
 class QPointF;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class SceneInspectorInterface : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit SceneInspectorInterface(QObject *parent = 0);
     virtual ~SceneInspectorInterface();
 
     virtual void initializeGui() = 0;
 
-    static void paintItemDecoration(QGraphicsItem *item, const QTransform &transform, QPainter *painter);
+    static void paintItemDecoration(QGraphicsItem *item, const QTransform &transform,
+                                    QPainter *painter);
 
-  public slots:
+public slots:
     virtual void renderScene(const QTransform &transform, const QSize &size) = 0;
     virtual void sceneClicked(const QPointF &pos) = 0;
 
-  signals:
+signals:
     void sceneRectChanged(const QRectF &rect);
     void sceneChanged();
     void sceneRendered(const QPixmap &view);
     void itemSelected(const QRectF &boundingRect);
 };
-
 }
 
+QT_BEGIN_NAMESPACE
 Q_DECLARE_INTERFACE(GammaRay::SceneInspectorInterface, "com.kdab.GammaRay.SceneInspector")
+QT_END_NAMESPACE
 
 #endif // GAMMARAY_SCENEINSPECTORINTERFACE_H
