@@ -33,6 +33,10 @@
 
 #include <core/remote/serverproxymodel.h>
 
+#include <common/objectbroker.h>
+#include <common/objectid.h>
+
+#include <QItemSelectionModel>
 #include <QTimer>
 
 using namespace GammaRay;
@@ -46,12 +50,16 @@ SignalMonitor::SignalMonitor(ProbeInterface *probe, QObject *parent)
     auto proxy = new ServerProxyModel<QSortFilterProxyModel>(this);
     proxy->setDynamicSortFilter(true);
     proxy->setSourceModel(model);
+    m_objModel = proxy;
     probe->registerModel(QStringLiteral("com.kdab.GammaRay.SignalHistoryModel"), proxy);
+    m_objSelectionModel = ObjectBroker::selectionModel(proxy);
 
     m_clock = new QTimer(this);
     m_clock->setInterval(1000/25); // update frequency of the delegate, we could slow this down a lot, and let the client interpolate, if necessary
     m_clock->setSingleShot(false);
     connect(m_clock, SIGNAL(timeout()), this, SLOT(timeout()));
+
+    connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)), this, SLOT(objectSelected(QObject*)));
 }
 
 SignalMonitor::~SignalMonitor()
@@ -71,6 +79,17 @@ void SignalMonitor::sendClockUpdates(bool enabled)
         m_clock->stop();
 }
 
+void SignalMonitor::objectSelected(QObject* obj)
+{
+    const auto indexList = m_objModel->match(m_objModel->index(0, 0), SignalHistoryModel::ObjectIdRole,
+        QVariant::fromValue<ObjectId>(ObjectId(obj)), 1, Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchWrap);
+    if (indexList.isEmpty())
+        return;
+
+    const auto index = indexList.first();
+    m_objSelectionModel->select(index, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
+}
+
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 Q_EXPORT_PLUGIN(SignalMonitorFactory)
 #endif
