@@ -33,10 +33,13 @@
 #include "signalmonitorclient.h"
 #include "signalmonitorcommon.h"
 
+#include <ui/contextmenuextension.h>
 #include <ui/searchlinecontroller.h>
 
 #include <common/objectbroker.h>
 
+#include <QMenu>
+
 #include <cmath>
 
 using namespace GammaRay;
@@ -66,6 +69,10 @@ SignalMonitorWidget::SignalMonitorWidget(QWidget *parent)
     ui->objectTreeView->header()->setObjectName("objectTreeViewHeader");
     ui->objectTreeView->setModel(signalHistory);
     ui->objectTreeView->setEventScrollBar(ui->eventScrollBar);
+    connect(ui->objectTreeView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(contextMenu(QPoint)));
+    auto selectionModel = ObjectBroker::selectionModel(signalHistory);
+    ui->objectTreeView->setSelectionModel(selectionModel);
+    connect(selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(selectionChanged(QItemSelection)));
 
     connect(ui->pauseButton, SIGNAL(toggled(bool)), this, SLOT(pauseAndResume(bool)));
     connect(ui->intervalScale, SIGNAL(valueChanged(int)), this,
@@ -120,6 +127,31 @@ void SignalMonitorWidget::eventDelegateIsActiveChanged(bool active)
     ui->pauseButton->setChecked(!active);
 }
 
+void SignalMonitorWidget::contextMenu(QPoint pos)
+{
+    auto index = ui->objectTreeView->indexAt(pos);
+    if (!index.isValid())
+        return;
+    index = index.sibling(index.row(), 0);
+
+    const auto objectId = index.data(SignalHistoryModel::ObjectIdRole).value<ObjectId>();
+    if (objectId.isNull())
+        return;
+
+    QMenu menu;
+    ContextMenuExtension ext(objectId);
+    ext.populateMenu(&menu);
+    menu.exec(ui->objectTreeView->viewport()->mapToGlobal(pos));
+}
+
+void SignalMonitorWidget::selectionChanged(const QItemSelection& selection)
+{
+    if (selection.isEmpty())
+        return;
+    const auto idx = selection.at(0).topLeft();
+    ui->objectTreeView->scrollTo(idx);
+}
+
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 Q_EXPORT_PLUGIN(SignalMonitorUiFactory)
 #endif
