@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
   Author: Milian Wolff <milian.wolff@kdab.com>
 
@@ -41,24 +41,25 @@
 
 #include <config-gammaray.h>
 
+QT_BEGIN_NAMESPACE
 class QAbstractTransition;
 class QStateMachine;
 class QAbstractState;
 class QAbstractItemModel;
 class QAbstractProxyModel;
 class QModelIndex;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class StateModel;
 class StateMachineWatcher;
 class TransitionModel;
 
 class StateMachineViewerServer : public StateMachineViewerInterface
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::StateMachineViewerInterface)
-  public:
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::StateMachineViewerInterface)
+public:
     explicit StateMachineViewerServer(ProbeInterface *probe, QObject *parent = 0);
 
     void addState(QAbstractState *state);
@@ -67,7 +68,7 @@ class StateMachineViewerServer : public StateMachineViewerInterface
     QStateMachine *selectedStateMachine() const;
 
     using StateMachineViewerInterface::stateConfigurationChanged;
-  private slots:
+private slots:
     void stateEntered(QAbstractState *state);
     void stateExited(QAbstractState *state);
     void stateConfigurationChanged();
@@ -75,17 +76,16 @@ class StateMachineViewerServer : public StateMachineViewerInterface
 
     void stateSelectionChanged();
 
-    void setFilteredStates(const QVector<QAbstractState*> &states);
-    void setMaximumDepth(int depth) Q_DECL_OVERRIDE;
+    void setFilteredStates(const QVector<QAbstractState *> &states);
     void selectStateMachine(int row) Q_DECL_OVERRIDE;
-    void setSelectedStateMachine(QStateMachine* machine);
+    void setSelectedStateMachine(QStateMachine *machine);
 
     void updateStartStop();
     void toggleRunning() Q_DECL_OVERRIDE;
 
     void repopulateGraph() Q_DECL_OVERRIDE;
 
-  private:
+private:
     void registerTypes();
     void updateStateItems();
 
@@ -97,29 +97,26 @@ class StateMachineViewerServer : public StateMachineViewerInterface
     TransitionModel *m_transitionModel;
 
     // filters
-    QVector<QAbstractState*> m_filteredStates;
-    int m_maximumDepth;
+    QVector<QAbstractState *> m_filteredStates;
 
     StateMachineWatcher *m_stateMachineWatcher;
-    QSet<QAbstractState*> m_recursionGuard;
-    QSet<QAbstractState*> m_lastStateConfig;
+    QSet<QAbstractState *> m_recursionGuard;
+    QSet<QAbstractState *> m_lastStateConfig;
 };
 
-class StateMachineViewerFactory :
-public QObject, public StandardToolFactory<QStateMachine, StateMachineViewerServer>
+class StateMachineViewerFactory : public QObject,
+    public StandardToolFactory<QStateMachine, StateMachineViewerServer>
 {
-  Q_OBJECT
-  Q_INTERFACES(GammaRay::ToolFactory)
-  Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_statemachineviewer.json")
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::ToolFactory)
+    Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolFactory" FILE "gammaray_statemachineviewer.json")
 
-  public:
-    explicit StateMachineViewerFactory(QObject *parent = 0) : QObject(parent)
+public:
+    explicit StateMachineViewerFactory(QObject *parent = 0)
+        : QObject(parent)
     {
     }
-
-    QString name() const Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_STATEMACHINEVIEWERSERVER_H
