@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -25,27 +30,25 @@
 
 using namespace GammaRay;
 
-StyleElementProxyModel::StyleModelProxy(QObject *parent)
-  : QIdentityProxyModel(parent)
-  , m_sizeHint(64, 64)
+StyleElementProxyModel::StyleModelProxy(QObject *parent) : QIdentityProxyModel(parent), m_sizeHint(
+        64, 64)
 {
 }
 
 void StyleElementProxyModel::setWidth(int width)
 {
-  m_sizeHint.setWidth(width);
+    m_sizeHint.setWidth(width);
 }
 
 void StyleElementProxyModel::setHeight(int height)
 {
-  m_sizeHint.setHeight(height);
+    m_sizeHint.setHeight(height);
 }
 
 QVariant StyleElementProxyModel::data(const QModelIndex &proxyIndex, int role) const
 {
-  if (role == Qt::SizeHintRole) {
-    return m_sizeHint;
-  }
+    if (role == Qt::SizeHintRole)
+        return m_sizeHint;
 
-  return QAbstractProxyModel::data(proxyIndex, role);
+    return QAbstractProxyModel::data(proxyIndex, role);
 }
