@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Milian Wolff <milian.wolff@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -26,14 +31,15 @@
 
 #include <QObject>
 
+QT_BEGIN_NAMESPACE
 class QSize;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
 class StyleInspectorInterface : public QObject
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit StyleInspectorInterface(QObject *parent = 0);
     virtual ~StyleInspectorInterface();
 
@@ -42,22 +48,23 @@ class StyleInspectorInterface : public QObject
     int cellZoom() const;
     QSize cellSizeHint() const;
 
-  signals:
+signals:
     void cellSizeChanged();
 
-  public slots:
+public slots:
     virtual void setCellHeight(int height);
     virtual void setCellWidth(int width);
     virtual void setCellZoom(int zoom);
 
-  private:
+private:
     int m_cellHeight;
     int m_cellWidth;
     int m_cellZoom;
 };
-
 }
 
+QT_BEGIN_NAMESPACE
 Q_DECLARE_INTERFACE(GammaRay::StyleInspectorInterface, "com.kdab.GammaRay.StyleInspectorInterface")
+QT_END_NAMESPACE
 
 #endif // GAMMARAY_STYLEINSPECTORINTERFACE_H
