@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -24,28 +29,34 @@
 #ifndef GAMMARAY_STYLEINSPECTOR_STYLEINSPECTORWIDGET_H
 #define GAMMARAY_STYLEINSPECTOR_STYLEINSPECTORWIDGET_H
 
+#include <ui/tooluifactory.h>
 #include <QWidget>
 
 namespace GammaRay {
-
 namespace Ui {
-  class StyleInspectorWidget;
+class StyleInspectorWidget;
 }
 
 class StyleInspectorWidget : public QWidget
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit StyleInspectorWidget(QWidget *parent = 0);
     virtual ~StyleInspectorWidget();
 
-  private slots:
+private slots:
     void styleSelected(int index);
 
-  private:
+private:
     Ui::StyleInspectorWidget *ui;
 };
 
+class StyleInspectorUiFactory : public QObject, public StandardToolUiFactory<StyleInspectorWidget>
+{
+    Q_OBJECT
+    Q_INTERFACES(GammaRay::ToolUiFactory)
+    Q_PLUGIN_METADATA(IID "com.kdab.GammaRay.ToolUiFactory" FILE "gammaray_styleinspector.json")
+};
 }
 
 #endif // GAMMARAY_STYLEINSPECTORWIDGET_H
