@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -24,19 +29,17 @@
 #ifndef GAMMARAY_WIDGETINSPECTOR_UIEXTRACTOR_H
 #define GAMMARAY_WIDGETINSPECTOR_UIEXTRACTOR_H
 
-#include "config-gammaray.h"
+#include <config-gammaray.h>
 
 #ifdef HAVE_QT_DESIGNER
 #include <QFormBuilder>
 
 namespace GammaRay {
-
 class UiExtractor : public QFormBuilder
 {
-  protected:
-    virtual bool checkProperty(QObject *obj, const QString &prop) const;
+protected:
+    bool checkProperty(QObject *obj, const QString &prop) const Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif
