@@ -54,24 +54,29 @@
 #include "common/modelutils.h"
 #include "common/objectmodel.h"
 #include "common/paths.h"
+#include <common/probecontrollerinterface.h>
 #include <common/remoteviewframe.h>
 
 #include <3rdparty/kde/krecursivefilterproxymodel.h>
 
+#include <QAction>
 #include <QAbstractItemView>
 #include <QApplication>
+#include <QButtonGroup>
 #include <QComboBox>
 #include <QDesktopWidget>
 #include <QDialog>
+#include <QItemSelectionModel>
 #include <QLayout>
 #include <QLibrary>
-#include <QItemSelectionModel>
+#include <QMenu>
 #include <QPainter>
 #include <QPixmap>
 #include <QMainWindow>
 #include <QMouseEvent>
 #include <QEvent>
 #include <QStyle>
+#include <QToolButton>
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 #include <QWindow>
 #endif
@@ -79,15 +84,27 @@
 #include <iostream>
 
 Q_DECLARE_METATYPE(const QStyle *)
+Q_DECLARE_METATYPE(QSizePolicy::ControlType)
 Q_DECLARE_METATYPE(QSizePolicy::ControlTypes)
 #if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 Q_DECLARE_METATYPE(Qt::Orientations)
 Q_DECLARE_METATYPE(Qt::Alignment)
+Q_DECLARE_METATYPE(QSizePolicy::Policy)
 #endif
 
 using namespace GammaRay;
 using namespace std;
 
+static bool isGoodCandidateWidget(QWidget *widget)
+{
+    if (!widget->isVisible() || widget->testAttribute(Qt::WA_NoSystemBackground) ||
+            widget->metaObject() == &QWidget::staticMetaObject) {
+        return false;
+    }
+
+    return true;
+}
+
 WidgetInspectorServer::WidgetInspectorServer(ProbeInterface *probe, QObject *parent)
     : WidgetInspectorInterface(parent)
     , m_externalExportActions(new QLibrary(this))
@@ -129,7 +146,9 @@ WidgetInspectorServer::WidgetInspectorServer(ProbeInterface *probe, QObject *par
     connect(probe->probe(), SIGNAL(objectSelected(QObject*,QPoint)), this,
             SLOT(objectSelected(QObject*)));
 
-    connect(m_remoteView, SIGNAL(doPickElement(QPoint)), this, SLOT(pickElement(QPoint)));
+    connect(m_remoteView, SIGNAL(elementsAtRequested(QPoint,GammaRay::RemoteViewInterface::RequestMode)), this, SLOT(requestElementsAt(QPoint,GammaRay::RemoteViewInterface::RequestMode)));
+    connect(this, SIGNAL(elementsAtReceived(GammaRay::ObjectIds,int)), m_remoteView, SIGNAL(elementsAtReceived(GammaRay::ObjectIds,int)));
+    connect(m_remoteView, SIGNAL(doPickElementId(GammaRay::ObjectId)), this, SLOT(pickElementId(GammaRay::ObjectId)));
 
     checkFeatures();
 }
@@ -170,7 +189,7 @@ void WidgetInspectorServer::widgetSelected(const QItemSelection &selection)
         m_remoteView->resetView();
     m_selectedWidget = widget;
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-    m_remoteView->setEventReceiver(m_selectedWidget->window()->windowHandle());
+    m_remoteView->setEventReceiver(m_selectedWidget ? m_selectedWidget->window()->windowHandle() : Q_NULLPTR);
 #endif
 
     if (m_selectedWidget
@@ -213,9 +232,13 @@ bool WidgetInspectorServer::eventFilter(QObject *object, QEvent *event)
             if (widget) {
                 // also select the corresponding model if a view was selected
                 if (QAbstractItemView *view = Util::findParentOfType<QAbstractItemView>(object))
-                    m_probe->selectObject(view->model());
+                    m_probe->selectObject(view->selectionModel());
                 else if (QComboBox *box = Util::findParentOfType<QComboBox>(object))
                     m_probe->selectObject(box->model());
+                else if (auto toolButton = qobject_cast<QToolButton*>(object)) {
+                    if (toolButton->defaultAction())
+                        m_probe->selectObject(toolButton->defaultAction());
+                }
 
                 m_probe->selectObject(widget, widget->mapFromGlobal(mouseEv->globalPos()));
                 widgetSelected(widget);
@@ -236,6 +259,27 @@ void WidgetInspectorServer::updateWidgetPreview()
     m_remoteView->sendFrame(frame);
 }
 
+void WidgetInspectorServer::requestElementsAt(const QPoint &pos, GammaRay::RemoteViewInterface::RequestMode mode)
+{
+    if (!m_selectedWidget)
+        return;
+    auto window = m_selectedWidget->window();
+
+    int bestCandidate;
+    const ObjectIds objects = recursiveWidgetsAt(window, pos, mode, bestCandidate);
+
+    if (!objects.isEmpty()) {
+        emit elementsAtReceived(objects, bestCandidate);
+    }
+}
+
+void WidgetInspectorServer::pickElementId(const GammaRay::ObjectId &id)
+{
+    QWidget *widget = id.asQObjectType<QWidget *>();
+    if (widget)
+        widgetSelected(widget);
+}
+
 QImage WidgetInspectorServer::imageForWidget(QWidget *widget)
 {
     // prevent "recursion", i.e. infinite update loop, in our eventFilter
@@ -337,18 +381,75 @@ void WidgetInspectorServer::saveAsUiFile(const QString &fileName)
     callExternalExportAction("gammaray_save_widget_to_ui", m_selectedWidget, fileName);
 }
 
+GammaRay::ObjectIds WidgetInspectorServer::recursiveWidgetsAt(QWidget *parent, const QPoint &pos,
+                                                              GammaRay::RemoteViewInterface::RequestMode mode, int &bestCandidate) const
+{
+    Q_ASSERT(parent);
+    ObjectIds objects;
+
+    bestCandidate = -1;
+
+    const auto childItems = parent->children();
+    for (int i = childItems.size() - 1; i >= 0; --i) { // backwards to match z order
+        auto c = childItems.at(i);
+        if (!c->isWidgetType() || c->metaObject()->className() == QLatin1String("GammaRay::OverlayWidget"))
+            continue;
+        auto w = qobject_cast<QWidget *>(c);
+        const QPoint p = w->mapFromParent(pos);
+
+        if (w->rect().contains(p, true)) {
+            const bool hasSubChildren = !w->children().isEmpty();
+
+            if (hasSubChildren) {
+                const int count = objects.count();
+                int bc;
+                objects << recursiveWidgetsAt(w, p, mode, bc);
+
+                if (bestCandidate == -1 && bc != -1) {
+                    bestCandidate = count + bc;
+                }
+            }
+            else {
+                if (bestCandidate == -1 && isGoodCandidateWidget(w)) {
+                    bestCandidate = objects.count();
+                }
+
+                objects << ObjectId(w);
+            }
+        }
+
+        if (bestCandidate != -1 && mode == RemoteViewInterface::RequestBest) {
+            break;
+        }
+    }
+
+    if (bestCandidate == -1 && isGoodCandidateWidget(parent)) {
+        bestCandidate = objects.count();
+    }
+
+    objects << ObjectId(parent);
+
+    if (bestCandidate != -1 && mode == RemoteViewInterface::RequestBest) {
+        objects = ObjectIds() << objects[bestCandidate];
+        bestCandidate = 0;
+    }
+
+    return objects;
+}
+
 void WidgetInspectorServer::callExternalExportAction(const char *name, QWidget *widget,
                                                      const QString &fileName)
 {
     if (!m_externalExportActions->isLoaded()) {
-        m_externalExportActions->setFileName(
-            Paths::currentPluginsPath() + QLatin1String("/libgammaray_widget_export_actions")
+        foreach (const auto &path, Paths::pluginPaths(GAMMARAY_PROBE_ABI)) {
+            m_externalExportActions->setFileName(path + QLatin1String("/libgammaray_widget_export_actions")
 #if defined(GAMMARAY_INSTALL_QT_LAYOUT)
-            + QStringLiteral("-") + QStringLiteral(GAMMARAY_PROBE_ABI)
+                + QStringLiteral("-") + QStringLiteral(GAMMARAY_PROBE_ABI)
 #endif
             );
-
-        m_externalExportActions->load();
+            if (m_externalExportActions->load())
+                break;
+        }
     }
 
     void (*function)(QWidget *, const QString &)
@@ -375,17 +476,6 @@ void WidgetInspectorServer::analyzePainting()
     m_overlayWidget->show();
 }
 
-void WidgetInspectorServer::pickElement(const QPoint &pos)
-{
-    if (!m_selectedWidget)
-        return;
-    auto child = m_selectedWidget->window()->childAt(pos);
-    if (!child && m_selectedWidget->window()->rect().contains(pos))
-        widgetSelected(m_selectedWidget->window());
-    else
-        widgetSelected(child);
-}
-
 void WidgetInspectorServer::checkFeatures()
 {
     Features f = NoFeature;
@@ -442,6 +532,9 @@ void WidgetInspectorServer::registerWidgetMetaTypes()
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     MO_ADD_PROPERTY_RO(QWidget, QWindow*, windowHandle);
 #endif
+#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
+    MO_ADD_PROPERTY   (QWidget, Qt::WindowFlags, windowFlags, setWindowFlags);
+#endif
 
     MO_ADD_METAOBJECT1(QStyle, QObject);
     MO_ADD_PROPERTY_RO(QStyle, const QStyle *, proxy);
@@ -467,6 +560,34 @@ void WidgetInspectorServer::registerWidgetMetaTypes()
 
     MO_ADD_METAOBJECT1(QComboBox, QWidget);
     MO_ADD_PROPERTY_RO(QComboBox, QAbstractItemModel *, model);
+
+    MO_ADD_METAOBJECT1(QAbstractButton, QWidget);
+    MO_ADD_PROPERTY_RO(QAbstractButton, QButtonGroup*, group);
+
+    MO_ADD_METAOBJECT1(QToolButton, QAbstractButton);
+    MO_ADD_PROPERTY_RO(QToolButton, QAction*, defaultAction);
+    MO_ADD_PROPERTY_RO(QToolButton, QMenu*, menu);
+#endif
+
+    MO_ADD_METAOBJECT0(QSizePolicy);
+    MO_ADD_PROPERTY   (QSizePolicy, QSizePolicy::ControlType, controlType, setControlType);
+    MO_ADD_PROPERTY_RO(QSizePolicy, Qt::Orientations, expandingDirections);
+    MO_ADD_PROPERTY   (QSizePolicy, bool, hasHeightForWidth, setHeightForWidth);
+    MO_ADD_PROPERTY   (QSizePolicy, bool, hasWidthForHeight, setWidthForHeight);
+    MO_ADD_PROPERTY   (QSizePolicy, QSizePolicy::Policy, horizontalPolicy, setHorizontalPolicy);
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+    MO_ADD_PROPERTY_RO(QSizePolicy, int, horizontalStretch);
+#else
+    MO_ADD_PROPERTY   (QSizePolicy, int, horizontalStretch, setHorizontalStretch);
+#endif
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+    MO_ADD_PROPERTY   (QSizePolicy, bool, retainSizeWhenHidden, setRetainSizeWhenHidden);
+#endif
+    MO_ADD_PROPERTY   (QSizePolicy, QSizePolicy::Policy, verticalPolicy, setVerticalPolicy);
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+    MO_ADD_PROPERTY_RO(QSizePolicy, int, verticalStretch);
+#else
+    MO_ADD_PROPERTY   (QSizePolicy, int, verticalStretch, setVerticalStretch);
 #endif
 }
 
@@ -486,10 +607,10 @@ static QString sizePolicyToString(const QSizePolicy &policy)
 void WidgetInspectorServer::registerVariantHandlers()
 {
     VariantHandler::registerStringConverter<QSizePolicy>(sizePolicyToString);
+    VariantHandler::registerStringConverter<const QStyle*>(Util::displayString);
 
 #if (QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
     VariantHandler::registerStringConverter<QWidget *>(Util::displayString);
-    VariantHandler::registerStringConverter<const QStyle *>(Util::displayString);
 #endif
 }
 
