@@ -2,7 +2,7 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2013-2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2013-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
   Licensees holding valid commercial KDAB GammaRay licenses may use this file in
@@ -48,16 +48,18 @@ static void connectObjects(QObject *sender, QObject *receiver)
     QObject::connect(sender, SIGNAL(mySignal1()), receiver, SLOT(mySlot1()));
     QObject::connect(sender, SIGNAL(mySignal2()), receiver, SLOT(mySlot2()), Qt::DirectConnection);
     QObject::connect(sender, SIGNAL(mySignal3()), receiver, SLOT(mySlot3()), Qt::QueuedConnection);
-    QObject::connect(sender, SIGNAL(mySignal4()), receiver, SLOT(mySlot4()), Qt::BlockingQueuedConnection);
+    QObject::connect(sender, SIGNAL(mySignal4()), receiver, SLOT(
+                         mySlot4()), Qt::BlockingQueuedConnection);
 }
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
 static void dummyFunction()
 {
 }
+
 #endif
 
-int main(int argc, char** argv)
+int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
 
@@ -107,4 +109,3 @@ int main(int argc, char** argv)
 }
 
 #include "connectionstest.moc"
-
