@@ -30,6 +30,7 @@
 #include <probe/hooks.h>
 #include <probe/probecreator.h>
 #include <core/probe.h>
+#include <core/toolmanager.h>
 #include <common/paths.h>
 #include <common/objectbroker.h>
 #include <common/remoteviewinterface.h>
@@ -57,7 +58,7 @@ private:
     void createProbe()
     {
         Paths::setRelativeRootPath(GAMMARAY_INVERSE_BIN_DIR);
-        qputenv("GAMMARAY_ProbePath", Paths::currentProbePath().toUtf8());
+        qputenv("GAMMARAY_ProbePath", Paths::probePath(GAMMARAY_PROBE_ABI).toUtf8());
         Hooks::installHooks();
         Probe::startupHookReceived();
         new ProbeCreator(ProbeCreator::Create);
@@ -191,15 +192,10 @@ private slots:
 
     void testItemPicking()
     {
-        auto toolModel = ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.ToolModel"));
-        QVERIFY(toolModel);
-
         QVERIFY(showSource(QStringLiteral("qrc:/manual/reparenttest.qml")));
 
-        auto toolSelectionModel = ObjectBroker::selectionModel(toolModel);
-        QVERIFY(toolSelectionModel);
-        QSignalSpy toolSpy(toolSelectionModel, SIGNAL(selectionChanged(QItemSelection,
-                                                                       QItemSelection)));
+        ToolManagerInterface *toolManager = ObjectBroker::object<ToolManagerInterface *>();
+        QSignalSpy toolSpy(toolManager, SIGNAL(toolSelected(QString)));
         QVERIFY(toolSpy.isValid());
 
         auto itemSelectionModel = ObjectBroker::selectionModel(itemModel);
@@ -210,8 +206,7 @@ private slots:
 
         auto sgSelectionModel = ObjectBroker::selectionModel(sgModel);
         QVERIFY(sgModel);
-        QSignalSpy sgSpy(sgSelectionModel,
-                         SIGNAL(selectionChanged(QItemSelection,QItemSelection)));
+        QSignalSpy sgSpy(sgSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)));
         QVERIFY(sgSpy.isValid());
 
         // auto center-click is broken before https://codereview.qt-project.org/141085/
@@ -253,8 +248,8 @@ private slots:
         QImage img = frame.image();
 
         QVERIFY(!img.isNull());
-        QCOMPARE(img.width(), 320);
-        QCOMPARE(img.height(), 160);
+        QCOMPARE(img.width(), static_cast<int>(view->width() *view->devicePixelRatio()));
+        QCOMPARE(img.height(), static_cast<int>(view->height() *view->devicePixelRatio()));
 #ifndef Q_OS_WIN // this is too unstable on the CI, rendered results seem to differ in color!?
         QCOMPARE(img.pixel(1, 1), QColor(QStringLiteral("lightsteelblue")).rgb());
 #endif
