@@ -79,7 +79,7 @@ QString AboutData::aboutBody()
 {
     return AboutDataContext::trUtf8(
         "<p>The Qt application inspection and manipulation tool."
-        "Learn more at <a href=\"http://www.kdab.com/gammaray\">http://www.kdab.com/gammaray/</a>.</p>"
+        "Learn more at <a href=\"https://www.kdab.com/gammaray\">https://www.kdab.com/gammaray/</a>.</p>"
         "<p>Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, "
         "a KDAB Group company, <a href=\"mailto:info@kdab.com\">info@kdab.com</a></p>"
         "<p>StackWalker code Copyright (c) 2005-2009, Jochen Kalmbach, All rights reserved<br>"
