@@ -31,7 +31,7 @@
 #include "ui_mainwindow.h"
 #include "aboutpluginsdialog.h"
 #include "aboutdialog.h"
-#include "clienttoolmodel.h"
+#include "clienttoolmanager.h"
 #include "aboutdata.h"
 #include "uiintegration.h"
 #include "helpcontroller.h"
@@ -41,7 +41,7 @@
 #include "common/endpoint.h"
 #include "common/probecontrollerinterface.h"
 
-#include "kde/krecursivefilterproxymodel.h"
+#include "kde/klinkitemselectionmodel.h"
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 #include <private/qguiplatformplugin_p.h>
@@ -59,6 +59,7 @@
 #include <QMenu>
 #include <QProcess>
 #include <QSettings>
+#include <QSortFilterProxyModel>
 #include <QStyleFactory>
 #include <QTableView>
 #include <QToolButton>
@@ -70,6 +71,9 @@
 #endif
 
 using namespace GammaRay;
+
+namespace {
+
 struct IdeSettings {
     const char * const app;
     const char * const args;
@@ -95,6 +99,39 @@ static const int ideSettingsSize = 0;
 static const int ideSettingsSize = sizeof(ideSettings) / sizeof(IdeSettings);
 #endif
 
+QStyle *gammarayStyleOverride()
+{
+    const auto styleNameOverride = QString::fromLocal8Bit(qgetenv("GAMMARAY_STYLE"));
+    if (styleNameOverride.isEmpty()) {
+        return nullptr;
+    }
+
+    if (!QStyleFactory::keys().contains(styleNameOverride)) {
+        qWarning() << "Style" << styleNameOverride << "does not exit (enabled by GAMMARAY_STYLE environment variable)";
+        qWarning() << "Existing styles: " << QStyleFactory::keys();
+    }
+
+    return QStyleFactory::create(styleNameOverride);
+}
+
+QStyle *gammarayDefaultStyle()
+{
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+    QGuiPlatformPlugin defaultGuiPlatform;
+    return QStyleFactory::create(defaultGuiPlatform.styleName());
+#else
+    foreach (const QString &styleName,
+             QGuiApplicationPrivate::platform_theme->themeHint(QPlatformTheme::StyleNames).
+             toStringList()) {
+        if (auto style = QStyleFactory::create(styleName)) {
+            return style;
+        }
+    }
+#endif
+    return nullptr;
+}
+}
+
 MainWindowUIStateManager::MainWindowUIStateManager(QWidget *widget)
     : UIStateManager(widget)
 {
@@ -115,31 +152,22 @@ MainWindow::MainWindow(QWidget *parent)
     , ui(new Ui::MainWindow)
     , m_stateManager(this)
 {
+    const auto styleOverride = gammarayStyleOverride();
+    if (styleOverride) {
+        applyStyle(styleOverride);
+    }
+
     if (!Endpoint::instance()->isRemoteClient()) {
         // we don't want application styles to propagate to the GammaRay window,
-        // so set the platform default one.
-        // unfortunately, that's not recursive by default, unless we have a style sheet set
-        setStyleSheet(QStringLiteral("I_DONT_EXIST {}"));
+        // so set the platform default one if needed
 
-        QStyle *defaultStyle = 0;
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-        QGuiPlatformPlugin defaultGuiPlatform;
-        defaultStyle = QStyleFactory::create(defaultGuiPlatform.styleName());
-#else
-        foreach (const QString &styleName,
-                 QGuiApplicationPrivate::platform_theme->themeHint(QPlatformTheme::StyleNames).
-                 toStringList()) {
-            if ((defaultStyle = QStyleFactory::create(styleName)))
-                break;
-        }
-#endif
-        if (defaultStyle) {
-            // do not set parent of default style
-            // this will cause the style being deleted too early through ~QObject()
-            // other objects (e.g. the script engine debugger) still might have a
-            // reference on the style during destruction
-            setStyle(defaultStyle);
+        // check if the style is not already overwritten
+        if (!styleOverride) {
+            if (auto defaultStyle= gammarayDefaultStyle()) {
+                applyStyle(defaultStyle);
+            }
         }
+
     }
 
     ui->setupUi(this);
@@ -165,20 +193,20 @@ MainWindow::MainWindow(QWidget *parent)
 
     setWindowIcon(QIcon(QStringLiteral(":gammaray/GammaRay-128x128.png")));
 
-    QAbstractItemModel *model = ObjectBroker::model(QStringLiteral("com.kdab.GammaRay.ToolModel"));
-    ClientToolModel *toolModel = new ClientToolModel(this);
-    toolModel->setData(QModelIndex(), QVariant::fromValue<QWidget *>(
-                           this), ToolModelRole::ToolWidgetParent);
-    toolModel->setSourceModel(model);
-    ui->toolSelector->setModel(toolModel);
-    QItemSelectionModel *selectionModel = ObjectBroker::selectionModel(toolModel);
-    ui->toolSelector->setSelectionModel(selectionModel);
+    ClientToolManager *toolManager = new ClientToolManager(this);
+    toolManager->setToolParentWidget(this);
+
+    auto sourceModel = toolManager->model();
+    auto sourceSelectionModel = toolManager->selectionModel();
+    auto proxyModel = new QSortFilterProxyModel(this);
+    proxyModel->setSourceModel(sourceModel);
+    proxyModel->setDynamicSortFilter(true);
+    proxyModel->sort(0);
+    ui->toolSelector->setModel(proxyModel);
+    ui->toolSelector->setSelectionModel(new KLinkItemSelectionModel(proxyModel, sourceSelectionModel, sourceModel));
     ui->toolSelector->resize(ui->toolSelector->minimumSize());
-    connect(selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+    connect(toolManager->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
             SLOT(toolSelected()));
-    // ### see ContextMenuExtension, workaround for tool name lookup regression in 2.5
-    // remove ones we have the model-free tool handling changes merged
-    ObjectBroker::registerModelInternal(QStringLiteral("com.kdab.GammaRay.ClientToolModel"), toolModel);
 
     // hide unused tool bar for now
     ui->mainToolBar->setHidden(true);
@@ -187,11 +215,6 @@ MainWindow::MainWindow(QWidget *parent)
 
     selectInitialTool();
 
-#ifdef Q_OS_MAC
-    ui->groupBox->setFlat(true);
-    ui->horizontalLayout->setContentsMargins(0, 0, 0, 0);
-#endif
-
     // Code Navigation
     QAction *configAction = new QAction(QIcon::fromTheme(QStringLiteral(
                                                              "applications-development")),
@@ -268,8 +291,9 @@ void MainWindow::about()
     dialog.setWindowTitle(tr("About GammaRay"));
     dialog.setTitle(AboutData::aboutTitle());
     dialog.setText(AboutData::aboutBody());
-    dialog.setLogo(QStringLiteral(":gammaray/GammaRay-128x128.png"));
+    dialog.setLogo(QStringLiteral(":gammaray/GammaRay-Trademark-medium.png"));
     dialog.setWindowIcon(QPixmap(QStringLiteral(":gammaray/GammaRay-128x128.png")));
+    dialog.adjustSize();
     dialog.exec();
 }
 
@@ -292,7 +316,7 @@ void MainWindow::aboutKDAB()
            "frameworks to Qt. We continue to help develop parts of Qt and are one "
            "of the major contributors to the Qt Project. We can give advanced or "
            "standard trainings anywhere around the globe.</p>"
-           "<p>Please visit <a href='http://www.kdab.com'>http://www.kdab.com</a> "
+           "<p>Please visit <a href='https://www.kdab.com'>https://www.kdab.com</a> "
            "to meet the people who write code like this."
            "</p></qt>"));
     dialog.setLogo(QStringLiteral(":gammaray/kdablogo160.png"));
@@ -404,11 +428,14 @@ void MainWindow::navigateToCode(const QUrl &url, int lineNumber, int columnNumbe
         const auto ideIdx = settings.value(QStringLiteral("IDE"), -1).toInt();
 
         QString command;
+#if !defined(Q_OS_WIN) && !defined(Q_OS_OSX) // Remove this #if branch when adding real data to ideSettings for Windows/OSX.
         if (ideIdx >= 0 && ideIdx < ideSettingsSize) {
             command += ideSettings[ideIdx].app;
             command += ' ';
             command += ideSettings[ideIdx].args;
-        } else if (ideIdx == -1) {
+        } else
+#endif
+        if (ideIdx == -1) {
             command = settings.value(QStringLiteral("CustomCommand")).toString();
         } else {
             QDesktopServices::openUrl(QUrl(url));
@@ -448,6 +475,21 @@ void GammaRay::MainWindow::setCodeNavigationIDE(QAction *action)
     settings.setValue(QStringLiteral("IDE"), defaultIde);
 }
 
+void MainWindow::applyStyle(QStyle* style)
+{
+    qDebug() << "Using" << style << "style";
+
+    // note: do not set this as parent of default style
+    // this will cause the style being deleted too early through ~QObject()
+    // other objects (e.g. the script engine debugger) still might have a
+    // reference on the style during destruction
+    style->setParent(QCoreApplication::instance());
+
+    // unfortunately, setting the style is not recursive by default, unless we have a style sheet set
+    setStyleSheet(QStringLiteral("I_DONT_EXIST {}"));
+    setStyle(style);
+}
+
 QWidget *MainWindow::createErrorPage(const QModelIndex &index)
 {
     QLabel *page = new QLabel(this);
