@@ -86,6 +86,9 @@ private:
     void selectInitialTool();
     QWidget *createErrorPage(const QModelIndex &index);
 
+    /// apply custom style for GammaRay's main window
+    void applyStyle(QStyle* style);
+
     QScopedPointer<Ui::MainWindow> ui;
     MainWindowUIStateManager m_stateManager;
 };
