@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -26,26 +31,31 @@
 
 #include <QDialog>
 
+#include <ui/uistatemanager.h>
+
+QT_BEGIN_NAMESPACE
 class QAbstractItemModel;
+QT_END_NAMESPACE
 
 namespace GammaRay {
-
-namespace Ui { class MethodInvocationDialog; }
+namespace Ui {
+class MethodInvocationDialog;
+}
 
 class MethodInvocationDialog : public QDialog
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit MethodInvocationDialog(QWidget *parent = 0);
     ~MethodInvocationDialog();
 
     Qt::ConnectionType connectionType() const;
     void setArgumentModel(QAbstractItemModel *model);
 
-  private:
+private:
     QScopedPointer<Ui::MethodInvocationDialog> ui;
+    UIStateManager m_stateManager;
 };
-
 }
 
 #endif // GAMMARAY_METHODINVOCATIONDIALOG_H
