@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2012-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -26,30 +31,31 @@
 
 #include <QDialog>
 
-namespace GammaRay {
+#include <ui/uistatemanager.h>
 
+namespace GammaRay {
 class PropertyEditorFactory;
 
 class PaletteModel;
 
 namespace Ui {
-  class PaletteDialog;
+class PaletteDialog;
 }
 
 class PaletteDialog : public QDialog
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit PaletteDialog(const QPalette &palette, QWidget *parent = 0);
     virtual ~PaletteDialog();
 
     QPalette editedPalette() const;
 
-  private:
+private:
     Ui::PaletteDialog *ui;
+    UIStateManager m_stateManager;
     PaletteModel *m_model;
 };
-
 }
 
 #endif // GAMMARAY_PALETTEDIALOG_H
