@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,24 +32,22 @@
 #include <QListView>
 
 namespace GammaRay {
-
 class SidePane : public QListView
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit SidePane(QWidget *parent = 0);
-    virtual ~SidePane();
+    ~SidePane();
 
-    virtual QSize sizeHint() const;
-    virtual void setModel(QAbstractItemModel* model);
+    QSize sizeHint() const Q_DECL_OVERRIDE;
+    void setModel(QAbstractItemModel *model) Q_DECL_OVERRIDE;
 
-  protected:
-    virtual void resizeEvent(QResizeEvent *e);
+protected:
+    void resizeEvent(QResizeEvent *e) Q_DECL_OVERRIDE;
 
-  private slots:
+private slots:
     void updateSizeHint();
 };
-
 }
 
 #endif // GAMMARAY_SIDEPANE_H
