@@ -2,9 +2,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2011-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2011-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Stephen Kelly <stephen.kelly@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -22,28 +27,29 @@
 #ifndef GAMMARAY_LOCALEINSPECTOR_LOCALEINSPECTORWIDGET_H
 #define GAMMARAY_LOCALEINSPECTOR_LOCALEINSPECTORWIDGET_H
 
+#include <ui/uistatemanager.h>
+
 #include <QWidget>
 
 namespace GammaRay {
-
 namespace Ui {
-  class LocaleInspectorWidget;
+class LocaleInspectorWidget;
 }
 
 class LocaleInspectorWidget : public QWidget
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit LocaleInspectorWidget(QWidget *parent = 0);
     ~LocaleInspectorWidget();
 
-  private slots:
+private slots:
     void initSplitterPosition();
 
-  private:
+private:
     QScopedPointer<Ui::LocaleInspectorWidget> ui;
+    UIStateManager m_stateManager;
 };
-
 }
 
 #endif // GAMMARAY_LOCALEINSPECTORWIDGET_H
