@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2010-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Kevin Funk <kevin.funk@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -24,23 +29,33 @@
 #ifndef GAMMARAY_METAOBJECTBROWSERWIDGET_H
 #define GAMMARAY_METAOBJECTBROWSERWIDGET_H
 
+#include <ui/uistatemanager.h>
+
 #include <QWidget>
 
-namespace GammaRay {
+QT_BEGIN_NAMESPACE
+class QItemSelection;
+QT_END_NAMESPACE
 
+namespace GammaRay {
 class PropertyWidget;
+class DeferredTreeView;
 
 class MetaObjectBrowserWidget : public QWidget
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     explicit MetaObjectBrowserWidget(QWidget *parent = 0);
 
-  private:
-     PropertyWidget *m_propertyWidget;
-};
+private slots:
+    void selectionChanged(const QItemSelection &selection);
 
+private:
+    UIStateManager m_stateManager;
+    PropertyWidget *m_propertyWidget;
+    DeferredTreeView *m_treeView;
+};
 }
 
 #endif // GAMMARAY_METAOBJECTBROWSERWIDGET_H
