@@ -4,9 +4,14 @@
   This file is part of GammaRay, the Qt application inspection and
   manipulation tool.
 
-  Copyright (C) 2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  Copyright (C) 2014-2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Author: Volker Krause <volker.krause@kdab.com>
 
+  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
+  accordance with GammaRay Commercial License Agreement provided with the Software.
+
+  Contact info@kdab.com if any conditions of this licensing are not clear to you.
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 2 of the License, or
@@ -27,18 +32,16 @@
 #include <QSortFilterProxyModel>
 
 namespace GammaRay {
-
 /** Client-side part of the connections model. */
 class ConnectionsClientProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
-    explicit ConnectionsClientProxyModel(QObject* parent = 0);
+    explicit ConnectionsClientProxyModel(QObject *parent = 0);
     virtual ~ConnectionsClientProxyModel();
 
-    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
 };
-
 }
 
 #endif // GAMMARAY_CONNECTIONSCLIENTPROXYMODEL_H
